@@ -66,6 +66,35 @@ import java.util.ListResourceBundle;
 public class FormatData_nn extends ListResourceBundle {
     @Override
     protected final Object[][] getContents() {
+        final String[] metaValue_generic_narrow_AmPmMarkers = new String[] {
+            "f.m.",
+            "e.m.",
+            "mn.",
+            "",
+            "mg.",
+            "fm.",
+            "em.",
+            "",
+            "kv.",
+            "",
+            "nt.",
+            "",
+        };
+        final String[] metaValue_MonthAbbreviations = new String[] {
+            "jan.",
+            "feb.",
+            "mars",
+            "apr.",
+            "mai",
+            "juni",
+            "juli",
+            "aug.",
+            "sep.",
+            "okt.",
+            "nov.",
+            "des.",
+            "",
+        };
         final String[] metaValue_generic_DayNames = new String[] {
             "s\u00f8ndag",
             "m\u00e5ndag",
@@ -84,15 +113,6 @@ public class FormatData_nn extends ListResourceBundle {
             "fr.",
             "la.",
         };
-        final String[] metaValue_generic_DayNarrows = new String[] {
-            "S",
-            "M",
-            "T",
-            "O",
-            "T",
-            "F",
-            "L",
-        };
         final String[] metaValue_generic_QuarterNarrows = new String[] {
             "1",
             "2",
@@ -100,8 +120,8 @@ public class FormatData_nn extends ListResourceBundle {
             "4",
         };
         final String[] metaValue_generic_AmPmMarkers = new String[] {
-            "AM",
-            "PM",
+            "a.m.",
+            "p.m.",
             "midnatt",
             "",
             "p\u00e5 morgonen",
@@ -113,76 +133,31 @@ public class FormatData_nn extends ListResourceBundle {
             "p\u00e5 natta",
             "",
         };
-        final String[] metaValue_generic_narrow_AmPmMarkers = new String[] {
-            "f.m.",
-            "e.m.",
-            "",
-            "",
-            "",
-            "",
-            "",
-            "",
-            "",
-            "",
-            "",
-            "",
-        };
         final String[] metaValue_generic_TimePatterns = new String[] {
             "'kl'. HH:mm:ss zzzz",
             "HH:mm:ss z",
             "HH:mm:ss",
             "HH:mm",
         };
-        final String[] metaValue_java_time_generic_DatePatterns = new String[] {
-            "EEEE d. MMMM y G",
-            "d. MMMM y G",
-            "d. MMM y G",
-            "d.M.y G",
-        };
-        final String[] metaValue_generic_DatePatterns = new String[] {
-            "EEEE d. MMMM y GGGG",
-            "d. MMMM y GGGG",
-            "d. MMM y GGGG",
-            "d.M.y GGGG",
-        };
         final String metaValue_generic_DateFormatItem_yw = "'veke' w 'i' Y";
         final String metaValue_generic_DateFormatItem_MMMMW = "'veke' W 'i' MMMM";
-        final String metaValue_generic_DateFormatItem_MEd = "E d.M";
-        final String[] metaValue_MonthAbbreviations = new String[] {
-            "jan.",
-            "feb.",
-            "mars",
-            "apr.",
-            "mai",
-            "juni",
-            "juli",
-            "aug.",
-            "sep.",
-            "okt.",
-            "nov.",
-            "des.",
-            "",
-        };
-        final String metaValue_buddhist_DateFormatItem_EHm = "E HH:mm";
-        final String metaValue_buddhist_DateFormatItem_EHms = "E HH:mm:ss";
+        final String metaValue_DateFormatItem_EHm = "E HH:mm";
+        final String metaValue_DateFormatItem_EHms = "E HH:mm:ss";
         final Object[][] data = new Object[][] {
-            { "islamic-umalqura.DateFormatItem.EHms", metaValue_buddhist_DateFormatItem_EHms },
-            { "generic.DatePatterns", metaValue_generic_DatePatterns },
-            { "japanese.DateFormatItem.MMMMW", metaValue_generic_DateFormatItem_MMMMW },
-            { "japanese.AmPmMarkers", metaValue_generic_AmPmMarkers },
-            { "AmPmMarkers", metaValue_generic_AmPmMarkers },
-            { "java.time.japanese.DatePatterns", metaValue_java_time_generic_DatePatterns },
-            { "generic.DateFormatItem.yw", metaValue_generic_DateFormatItem_yw },
-            { "islamic-umalqura.DateFormatItem.EHm", metaValue_buddhist_DateFormatItem_EHm },
-            { "roc.DateFormatItem.EHms", metaValue_buddhist_DateFormatItem_EHms },
+            { "generic.DayNames", metaValue_generic_DayNames },
+            { "generic.DayAbbreviations", metaValue_generic_DayAbbreviations },
             { "generic.QuarterNarrows", metaValue_generic_QuarterNarrows },
-            { "calendarname.islamic-civil", "islamsk sivil kalender" },
-            { "japanese.TimePatterns", metaValue_generic_TimePatterns },
-            { "islamic-umalqura.DateFormatItem.MMMMW", metaValue_generic_DateFormatItem_MMMMW },
-            { "abbreviated.AmPmMarkers", metaValue_generic_narrow_AmPmMarkers },
-            { "japanese.abbreviated.AmPmMarkers", metaValue_generic_narrow_AmPmMarkers },
-            { "islamic.DateFormatItem.MMMMW", metaValue_generic_DateFormatItem_MMMMW },
-            { "DateFormatItem.MMMMW", metaValue_generic_DateFormatItem_MMMMW },
+            { "generic.AmPmMarkers", metaValue_generic_AmPmMarkers },
+            { "generic.narrow.AmPmMarkers", metaValue_generic_narrow_AmPmMarkers },
+            { "generic.abbreviated.AmPmMarkers", metaValue_generic_narrow_AmPmMarkers },
+            { "generic.TimePatterns", metaValue_generic_TimePatterns },
+            { "generic.DateFormatItem.yw", metaValue_generic_DateFormatItem_yw },
+            { "generic.DateFormatItem.MMMMW", metaValue_generic_DateFormatItem_MMMMW },
+            { "MonthAbbreviations", metaValue_MonthAbbreviations },
+            { "standalone.MonthAbbreviations", metaValue_MonthAbbreviations },
+            { "DayNames", metaValue_generic_DayNames },
+            { "standalone.DayNames", metaValue_generic_DayNames },
+            { "DayAbbreviations", metaValue_generic_DayAbbreviations },
             { "standalone.DayAbbreviations",
                 new String[] {
                     "s\u00f8n",
@@ -194,13 +169,24 @@ public class FormatData_nn extends ListResourceBundle {
                     "lau",
                 }
             },
-            { "roc.MonthAbbreviations", metaValue_MonthAbbreviations },
-            { "islamic-umalqura.DateFormatItem.yw", metaValue_generic_DateFormatItem_yw },
-            { "roc.QuarterNarrows", metaValue_generic_QuarterNarrows },
-            { "islamic.DayNames", metaValue_generic_DayNames },
-            { "DateFormatItem.yw", metaValue_generic_DateFormatItem_yw },
-            { "buddhist.MonthAbbreviations", metaValue_MonthAbbreviations },
-            { "buddhist.DateFormatItem.EHm", metaValue_buddhist_DateFormatItem_EHm },
+            { "QuarterNarrows", metaValue_generic_QuarterNarrows },
+            { "standalone.QuarterNarrows", metaValue_generic_QuarterNarrows },
+            { "AmPmMarkers", metaValue_generic_AmPmMarkers },
+            { "narrow.AmPmMarkers", metaValue_generic_narrow_AmPmMarkers },
+            { "abbreviated.AmPmMarkers", metaValue_generic_narrow_AmPmMarkers },
+            { "field.month", "m\u00e5nad" },
+            { "field.week", "veke" },
+            { "field.weekday", "vekedag" },
+            { "timezone.regionFormat.daylight", "sommartid \u2013 {0}" },
+            { "TimePatterns", metaValue_generic_TimePatterns },
+            { "DatePatterns",
+                new String[] {
+                    "EEEE d. MMMM y",
+                    "d. MMMM y",
+                    "d. MMM y",
+                    "dd.MM.y",
+                }
+            },
             { "DateTimePatterns",
                 new String[] {
                     "{1} {0}",
@@ -209,16 +195,74 @@ public class FormatData_nn extends ListResourceBundle {
                     "{1}, {0}",
                 }
             },
-            { "narrow.AmPmMarkers", metaValue_generic_narrow_AmPmMarkers },
+            { "PluralRules", "one:n = 1" },
+            { "DayPeriodRules", "midnight:00:00;night1:00:00-06:00;morning2:10:00-12:00;afternoon1:12:00-18:00;morning1:06:00-10:00;evening1:18:00-24:00" },
+            { "DateFormatItem.yw", metaValue_generic_DateFormatItem_yw },
+            { "DateFormatItem.EHm", metaValue_DateFormatItem_EHm },
+            { "DateFormatItem.MMMMW", metaValue_generic_DateFormatItem_MMMMW },
+            { "DateFormatItem.EHms", metaValue_DateFormatItem_EHms },
+            { "buddhist.MonthAbbreviations", metaValue_MonthAbbreviations },
+            { "buddhist.DayNames", metaValue_generic_DayNames },
+            { "buddhist.DayAbbreviations", metaValue_generic_DayAbbreviations },
+            { "buddhist.QuarterNarrows", metaValue_generic_QuarterNarrows },
+            { "buddhist.AmPmMarkers", metaValue_generic_AmPmMarkers },
+            { "buddhist.narrow.AmPmMarkers", metaValue_generic_narrow_AmPmMarkers },
+            { "buddhist.abbreviated.AmPmMarkers", metaValue_generic_narrow_AmPmMarkers },
+            { "buddhist.TimePatterns", metaValue_generic_TimePatterns },
+            { "buddhist.DateFormatItem.yw", metaValue_generic_DateFormatItem_yw },
+            { "buddhist.DateFormatItem.EHm", metaValue_DateFormatItem_EHm },
+            { "buddhist.DateFormatItem.MMMMW", metaValue_generic_DateFormatItem_MMMMW },
+            { "buddhist.DateFormatItem.EHms", metaValue_DateFormatItem_EHms },
+            { "japanese.MonthAbbreviations", metaValue_MonthAbbreviations },
+            { "japanese.DayNames", metaValue_generic_DayNames },
+            { "japanese.DayAbbreviations", metaValue_generic_DayAbbreviations },
+            { "japanese.QuarterNarrows", metaValue_generic_QuarterNarrows },
+            { "japanese.AmPmMarkers", metaValue_generic_AmPmMarkers },
+            { "japanese.abbreviated.AmPmMarkers", metaValue_generic_narrow_AmPmMarkers },
+            { "japanese.TimePatterns", metaValue_generic_TimePatterns },
+            { "japanese.DateFormatItem.yw", metaValue_generic_DateFormatItem_yw },
+            { "japanese.DateFormatItem.EHm", metaValue_DateFormatItem_EHm },
+            { "japanese.DateFormatItem.MMMMW", metaValue_generic_DateFormatItem_MMMMW },
+            { "japanese.DateFormatItem.EHms", metaValue_DateFormatItem_EHms },
+            { "roc.MonthAbbreviations", metaValue_MonthAbbreviations },
+            { "roc.DayNames", metaValue_generic_DayNames },
+            { "roc.DayAbbreviations", metaValue_generic_DayAbbreviations },
+            { "roc.QuarterNarrows", metaValue_generic_QuarterNarrows },
+            { "roc.AmPmMarkers", metaValue_generic_AmPmMarkers },
+            { "roc.abbreviated.AmPmMarkers", metaValue_generic_narrow_AmPmMarkers },
+            { "roc.TimePatterns", metaValue_generic_TimePatterns },
+            { "roc.DateFormatItem.yw", metaValue_generic_DateFormatItem_yw },
+            { "roc.DateFormatItem.EHm", metaValue_DateFormatItem_EHm },
+            { "roc.DateFormatItem.MMMMW", metaValue_generic_DateFormatItem_MMMMW },
+            { "roc.DateFormatItem.EHms", metaValue_DateFormatItem_EHms },
+            { "islamic.DayNames", metaValue_generic_DayNames },
+            { "islamic.DayAbbreviations", metaValue_generic_DayAbbreviations },
+            { "islamic.QuarterNarrows", metaValue_generic_QuarterNarrows },
+            { "islamic.AmPmMarkers", metaValue_generic_AmPmMarkers },
+            { "islamic.abbreviated.AmPmMarkers", metaValue_generic_narrow_AmPmMarkers },
+            { "islamic.TimePatterns", metaValue_generic_TimePatterns },
+            { "islamic.DateFormatItem.yw", metaValue_generic_DateFormatItem_yw },
+            { "islamic.DateFormatItem.EHm", metaValue_DateFormatItem_EHm },
+            { "islamic.DateFormatItem.MMMMW", metaValue_generic_DateFormatItem_MMMMW },
+            { "islamic.DateFormatItem.EHms", metaValue_DateFormatItem_EHms },
+            { "islamic-civil.DateFormatItem.yw", metaValue_generic_DateFormatItem_yw },
+            { "islamic-civil.DateFormatItem.EHm", metaValue_DateFormatItem_EHm },
+            { "islamic-civil.DateFormatItem.MMMMW", metaValue_generic_DateFormatItem_MMMMW },
+            { "islamic-civil.DateFormatItem.EHms", metaValue_DateFormatItem_EHms },
+            { "islamic-umalqura.DateFormatItem.yw", metaValue_generic_DateFormatItem_yw },
+            { "islamic-umalqura.DateFormatItem.EHm", metaValue_DateFormatItem_EHm },
+            { "islamic-umalqura.DateFormatItem.MMMMW", metaValue_generic_DateFormatItem_MMMMW },
+            { "islamic-umalqura.DateFormatItem.EHms", metaValue_DateFormatItem_EHms },
+            { "calendarname.islamic-civil", "islamsk sivil kalender" },
             { "latn.NumberElements",
                 new String[] {
-                    ".",
                     ",",
+                    "\u00a0",
                     ";",
                     "%",
                     "0",
                     "#",
-                    "-",
+                    "\u2212",
                     "E",
                     "\u2030",
                     "\u221e",
@@ -227,40 +271,22 @@ public class FormatData_nn extends ListResourceBundle {
                     "",
                 }
             },
-            { "japanese.DatePatterns", metaValue_generic_DatePatterns },
-            { "japanese.DateFormatItem.MEd", metaValue_generic_DateFormatItem_MEd },
-            { "buddhist.DayNames", metaValue_generic_DayNames },
-            { "buddhist.AmPmMarkers", metaValue_generic_AmPmMarkers },
-            { "japanese.QuarterNarrows", metaValue_generic_QuarterNarrows },
-            { "islamic.DatePatterns", metaValue_generic_DatePatterns },
-            { "generic.abbreviated.AmPmMarkers", metaValue_generic_narrow_AmPmMarkers },
-            { "islamic.DateFormatItem.EHms", metaValue_buddhist_DateFormatItem_EHms },
-            { "field.month", "m\u00e5nad" },
-            { "DayAbbreviations", metaValue_generic_DayAbbreviations },
-            { "DayNarrows", metaValue_generic_DayNarrows },
-            { "roc.DatePatterns", metaValue_generic_DatePatterns },
-            { "islamic-civil.DateFormatItem.yw", metaValue_generic_DateFormatItem_yw },
-            { "islamic.DateFormatItem.yw", metaValue_generic_DateFormatItem_yw },
-            { "DayPeriodRules", "midnight:00:00;night1:00:00-06:00;morning2:10:00-12:00;afternoon1:12:00-18:00;morning1:06:00-10:00;evening1:18:00-24:00" },
-            { "islamic-civil.DateFormatItem.EHm", metaValue_buddhist_DateFormatItem_EHm },
-            { "java.time.generic.DatePatterns", metaValue_java_time_generic_DatePatterns },
-            { "japanese.DateFormatItem.EHms", metaValue_buddhist_DateFormatItem_EHms },
-            { "generic.TimePatterns", metaValue_generic_TimePatterns },
-            { "roc.DateFormatItem.yw", metaValue_generic_DateFormatItem_yw },
-            { "DateFormatItem.MEd", metaValue_generic_DateFormatItem_MEd },
-            { "islamic.DateFormatItem.MEd", metaValue_generic_DateFormatItem_MEd },
-            { "generic.DayAbbreviations", metaValue_generic_DayAbbreviations },
-            { "buddhist.TimePatterns", metaValue_generic_TimePatterns },
-            { "buddhist.DateFormatItem.MMMMW", metaValue_generic_DateFormatItem_MMMMW },
-            { "standalone.MonthAbbreviations", metaValue_MonthAbbreviations },
+            { "latn.NumberPatterns",
+                new String[] {
+                    "#,##0.###",
+                    "#,##0.00\u00a0\u00a4",
+                    "#,##0\u00a0%",
+                    "#,##0.00\u00a0\u00a4",
+                }
+            },
             { "long.CompactNumberPatterns",
                 new String[] {
                     "",
                     "",
                     "",
-                    "",
-                    "",
-                    "",
+                    "{one:0' 'tusen other:0' 'tusen}",
+                    "{one:00' 'tusen other:00' 'tusen}",
+                    "{one:000' 'tusen other:000' 'tusen}",
                     "{one:0' 'million other:0' 'millionar}",
                     "{one:00' 'million other:00' 'millionar}",
                     "{one:000' 'million other:000' 'millionar}",
@@ -272,82 +298,6 @@ public class FormatData_nn extends ListResourceBundle {
                     "{one:000' 'billion other:000' 'billionar}",
                 }
             },
-            { "buddhist.QuarterNarrows", metaValue_generic_QuarterNarrows },
-            { "roc.DayAbbreviations", metaValue_generic_DayAbbreviations },
-            { "islamic.AmPmMarkers", metaValue_generic_AmPmMarkers },
-            { "roc.DateFormatItem.MEd", metaValue_generic_DateFormatItem_MEd },
-            { "generic.DateTimePatterns",
-                new String[] {
-                    "{1} {0}",
-                    "{1} {0}",
-                    "{1} {0}",
-                    "{1} {0}",
-                }
-            },
-            { "TimePatterns", metaValue_generic_TimePatterns },
-            { "islamic.DayNarrows", metaValue_generic_DayNarrows },
-            { "islamic-civil.DateFormatItem.MMMMW", metaValue_generic_DateFormatItem_MMMMW },
-            { "generic.DayNarrows", metaValue_generic_DayNarrows },
-            { "islamic.DateFormatItem.EHm", metaValue_buddhist_DateFormatItem_EHm },
-            { "buddhist.DateFormatItem.EHms", metaValue_buddhist_DateFormatItem_EHms },
-            { "buddhist.narrow.AmPmMarkers", metaValue_generic_narrow_AmPmMarkers },
-            { "buddhist.abbreviated.AmPmMarkers", metaValue_generic_narrow_AmPmMarkers },
-            { "roc.DayNames", metaValue_generic_DayNames },
-            { "islamic.abbreviated.AmPmMarkers", metaValue_generic_narrow_AmPmMarkers },
-            { "java.time.islamic.DatePatterns", metaValue_java_time_generic_DatePatterns },
-            { "field.weekday", "vekedag" },
-            { "roc.DateFormatItem.MMMMW", metaValue_generic_DateFormatItem_MMMMW },
-            { "buddhist.DateFormatItem.yw", metaValue_generic_DateFormatItem_yw },
-            { "japanese.MonthAbbreviations", metaValue_MonthAbbreviations },
-            { "islamic-civil.DateFormatItem.EHms", metaValue_buddhist_DateFormatItem_EHms },
-            { "generic.DayNames", metaValue_generic_DayNames },
-            { "islamic.DayAbbreviations", metaValue_generic_DayAbbreviations },
-            { "islamic-civil.DateFormatItem.MEd", metaValue_generic_DateFormatItem_MEd },
-            { "buddhist.DateFormatItem.MEd", metaValue_generic_DateFormatItem_MEd },
-            { "japanese.DayNames", metaValue_generic_DayNames },
-            { "japanese.DayAbbreviations", metaValue_generic_DayAbbreviations },
-            { "DayNames", metaValue_generic_DayNames },
-            { "generic.DateFormatItem.MEd", metaValue_generic_DateFormatItem_MEd },
-            { "buddhist.DatePatterns", metaValue_generic_DatePatterns },
-            { "japanese.DateFormatItem.EHm", metaValue_buddhist_DateFormatItem_EHm },
-            { "field.week", "veke" },
-            { "generic.DateFormatItem.MMMMW", metaValue_generic_DateFormatItem_MMMMW },
-            { "islamic.QuarterNarrows", metaValue_generic_QuarterNarrows },
-            { "roc.DayNarrows", metaValue_generic_DayNarrows },
-            { "islamic-umalqura.DateFormatItem.MEd", metaValue_generic_DateFormatItem_MEd },
-            { "roc.DateFormatItem.EHm", metaValue_buddhist_DateFormatItem_EHm },
-            { "roc.AmPmMarkers", metaValue_generic_AmPmMarkers },
-            { "java.time.buddhist.DatePatterns", metaValue_java_time_generic_DatePatterns },
-            { "java.time.roc.DatePatterns", metaValue_java_time_generic_DatePatterns },
-            { "timezone.regionFormat.daylight", "sommartid \u2013 {0}" },
-            { "DatePatterns",
-                new String[] {
-                    "EEEE d. MMMM y",
-                    "d. MMMM y",
-                    "d. MMM y",
-                    "dd.MM.y",
-                }
-            },
-            { "buddhist.DayAbbreviations", metaValue_generic_DayAbbreviations },
-            { "islamic.TimePatterns", metaValue_generic_TimePatterns },
-            { "standalone.DayNames", metaValue_generic_DayNames },
-            { "MonthAbbreviations", metaValue_MonthAbbreviations },
-            { "generic.narrow.AmPmMarkers", metaValue_generic_narrow_AmPmMarkers },
-            { "PluralRules", "one:n = 1" },
-            { "generic.AmPmMarkers", metaValue_generic_AmPmMarkers },
-            { "latn.NumberPatterns",
-                new String[] {
-                    "#,##0.###",
-                    "#,##0.00\u00a0\u00a4",
-                    "#,##0%",
-                    "#,##0.00\u00a0\u00a4",
-                }
-            },
-            { "buddhist.DayNarrows", metaValue_generic_DayNarrows },
-            { "japanese.DateFormatItem.yw", metaValue_generic_DateFormatItem_yw },
-            { "japanese.DayNarrows", metaValue_generic_DayNarrows },
-            { "roc.TimePatterns", metaValue_generic_TimePatterns },
-            { "roc.abbreviated.AmPmMarkers", metaValue_generic_narrow_AmPmMarkers },
         };
         return data;
     }
