@@ -66,83 +66,12 @@ import java.util.ListResourceBundle;
 public class FormatData_sat extends ListResourceBundle {
     @Override
     protected final Object[][] getContents() {
-        final String[] metaValue_generic_DayNames = new String[] {
-            "\u1c65\u1c64\u1c78\u1c5c\u1c6e",
-            "\u1c5a\u1c5b\u1c6e",
-            "\u1c75\u1c5f\u1c5e\u1c6e",
-            "\u1c65\u1c5f\u1c79\u1c5c\u1c69\u1c71",
-            "\u1c65\u1c5f\u1c79\u1c68\u1c6b\u1c64",
-            "\u1c61\u1c5f\u1c79\u1c68\u1c69\u1c62",
-            "\u1c67\u1c69\u1c66\u1c69\u1c62",
-        };
-        final String[] metaValue_generic_DayAbbreviations = new String[] {
-            "\u1c65\u1c64\u1c78",
-            "\u1c5a\u1c5b",
-            "\u1c75\u1c5f",
-            "\u1c65\u1c5f\u1c79",
-            "\u1c65\u1c5f\u1c79\u1c68",
-            "\u1c61\u1c5f\u1c79",
-            "\u1c67\u1c69",
-        };
-        final String[] metaValue_generic_DayNarrows = new String[] {
-            "\u1c65",
-            "\u1c5a",
-            "\u1c75",
-            "\u1c65",
-            "\u1c65",
-            "\u1c61",
-            "\u1c67",
-        };
         final String[] metaValue_generic_QuarterNames = new String[] {
             "\u1c51\u1c5f\u1c5c \u1c6f\u1c6e \u1c6a\u1c5f\u1c78\u1c6b\u1c5a\u1c60\u1c64\u1c6d\u1c5f\u1c79",
             "\u1c52\u1c5f\u1c5c \u1c6f\u1c6e \u1c6a\u1c5f\u1c78\u1c6b\u1c5a\u1c60\u1c64\u1c6d\u1c5f\u1c79",
             "\u1c53\u1c6d\u1c5f\u1c5c \u1c6f\u1c6e \u1c6a\u1c5f\u1c78\u1c6b\u1c5a\u1c60\u1c64\u1c6d\u1c5f\u1c79",
             "\u1c54\u1c5f\u1c5c \u1c6f\u1c6e \u1c6a\u1c5f\u1c78\u1c6b\u1c5a\u1c60\u1c64\u1c6d\u1c5f\u1c79",
         };
-        final String[] metaValue_generic_QuarterNarrows = new String[] {
-            "\u1c51",
-            "\u1c52",
-            "\u1c53",
-            "\u1c54",
-        };
-        final String[] metaValue_generic_AmPmMarkers = new String[] {
-            "\u1c65\u1c6e\u1c5b\u1c5f\u1c5c",
-            "\u1c67\u1c64\u1c6b\u1c5f\u1c79",
-            "",
-            "",
-            "",
-            "",
-            "",
-            "",
-            "",
-            "",
-            "",
-            "",
-        };
-        final String[] metaValue_generic_TimePatterns = new String[] {
-            "h:mm:ss a zzzz",
-            "h:mm:ss a z",
-            "h:mm:ss a",
-            "h:mm a",
-        };
-        final String[] metaValue_java_time_generic_DatePatterns = new String[] {
-            "G y MMMM d, EEEE",
-            "G y MMMM d",
-            "G y MMM d",
-            "GGGGG y-MM-dd",
-        };
-        final String[] metaValue_generic_DatePatterns = new String[] {
-            "GGGG y MMMM d, EEEE",
-            "GGGG y MMMM d",
-            "GGGG y MMM d",
-            "G y-MM-dd",
-        };
-        final String[] metaValue_generic_DateTimePatterns = new String[] {
-            "{1} {0}",
-            "{1} {0}",
-            "{1} {0}",
-            "{1} {0}",
-        };
         final String[] metaValue_MonthNames = new String[] {
             "\u1c61\u1c5f\u1c71\u1c63\u1c5f\u1c68\u1c64",
             "\u1c6f\u1c77\u1c5f\u1c68\u1c63\u1c5f\u1c68\u1c64",
@@ -188,37 +117,194 @@ public class FormatData_sat extends ListResourceBundle {
             "\u1c6b",
             "",
         };
+        final String[] metaValue_generic_DayNames = new String[] {
+            "\u1c65\u1c64\u1c78\u1c5c\u1c6e",
+            "\u1c5a\u1c5b\u1c6e",
+            "\u1c75\u1c5f\u1c5e\u1c6e",
+            "\u1c65\u1c5f\u1c79\u1c5c\u1c69\u1c71",
+            "\u1c65\u1c5f\u1c79\u1c68\u1c6b\u1c64",
+            "\u1c61\u1c5f\u1c79\u1c68\u1c69\u1c62",
+            "\u1c67\u1c69\u1c66\u1c69\u1c62",
+        };
+        final String[] metaValue_generic_DayAbbreviations = new String[] {
+            "\u1c65\u1c64\u1c78",
+            "\u1c5a\u1c5b",
+            "\u1c75\u1c5f",
+            "\u1c65\u1c5f\u1c79",
+            "\u1c65\u1c5f\u1c79\u1c68",
+            "\u1c61\u1c5f\u1c79",
+            "\u1c67\u1c69",
+        };
+        final String[] metaValue_generic_DayNarrows = new String[] {
+            "\u1c65",
+            "\u1c5a",
+            "\u1c75",
+            "\u1c65",
+            "\u1c65",
+            "\u1c61",
+            "\u1c67",
+        };
+        final String[] metaValue_generic_QuarterNarrows = new String[] {
+            "\u1c51",
+            "\u1c52",
+            "\u1c53",
+            "\u1c54",
+        };
+        final String[] metaValue_generic_AmPmMarkers = new String[] {
+            "\u1c65\u1c6e\u1c5b\u1c5f\u1c5c",
+            "\u1c67\u1c64\u1c6b\u1c5f\u1c79",
+            "",
+            "",
+            "",
+            "",
+            "",
+            "",
+            "",
+            "",
+            "",
+            "",
+        };
         final String[] metaValue_long_Eras = new String[] {
             "\u1c65\u1c6e\u1c68\u1c62\u1c5f \u1c5e\u1c5f\u1c66\u1c5f",
             "\u1c64\u1c65\u1c63\u1c64",
         };
+        final String[] metaValue_generic_TimePatterns = new String[] {
+            "h:mm:ss a zzzz",
+            "h:mm:ss a z",
+            "h:mm:ss a",
+            "h:mm a",
+        };
+        final String[] metaValue_generic_DateTimePatterns = new String[] {
+            "{1} {0}",
+            "{1} {0}",
+            "{1} {0}",
+            "{1} {0}",
+        };
+        final String[] metaValue_java_time_generic_DatePatterns = new String[] {
+            "G y MMMM d, EEEE",
+            "G y MMMM d",
+            "G y MMM d",
+            "GGGGG y-MM-dd",
+        };
+        final String[] metaValue_generic_DatePatterns = new String[] {
+            "GGGG y MMMM d, EEEE",
+            "GGGG y MMMM d",
+            "GGGG y MMM d",
+            "G y-MM-dd",
+        };
         final String metaValue_calendarname_gregorian = "\u1c5c\u1c68\u1c6e\u1c5c\u1c5a\u1c68\u1c64\u1c6d\u1c5f\u1c71 \u1c60\u1c5f\u1c5e\u1c6e\u1c71\u1c70\u1c5f\u1c68";
         final Object[][] data = new Object[][] {
-            { "MonthNames", metaValue_MonthNames },
-            { "field.year", "\u1c65\u1c6e\u1c68\u1c62\u1c5f/\u1c75\u1c5a\u1c6a\u1c77\u1c5a\u1c5e\u1c68" },
-            { "generic.DatePatterns", metaValue_generic_DatePatterns },
-            { "japanese.AmPmMarkers", metaValue_generic_AmPmMarkers },
-            { "AmPmMarkers", metaValue_generic_AmPmMarkers },
-            { "timezone.gmtFormat", "\u1c61\u1c64\u1c6e\u1c62\u1c74\u1c64{0}" },
-            { "java.time.japanese.DatePatterns", metaValue_java_time_generic_DatePatterns },
-            { "standalone.QuarterAbbreviations", metaValue_generic_QuarterNames },
-            { "roc.QuarterNames", metaValue_generic_QuarterNames },
+            { "generic.DayNames", metaValue_generic_DayNames },
+            { "generic.DayAbbreviations", metaValue_generic_DayAbbreviations },
+            { "generic.DayNarrows", metaValue_generic_DayNarrows },
+            { "generic.QuarterNames", metaValue_generic_QuarterNames },
+            { "generic.QuarterAbbreviations", metaValue_generic_QuarterNames },
             { "generic.QuarterNarrows", metaValue_generic_QuarterNarrows },
-            { "roc.MonthNarrows", metaValue_MonthNarrows },
-            { "japanese.TimePatterns", metaValue_generic_TimePatterns },
-            { "narrow.Eras", metaValue_long_Eras },
-            { "timezone.regionFormat.standard", "{0} \u1c6e\u1c74\u1c6e\u1c71\u1c70\u1c5f\u1c68\u1c70 \u1c5a\u1c60\u1c5b\u1c5a" },
-            { "DefaultNumberingSystem", "olck" },
-            { "timezone.gmtZeroFormat", "\u1c61\u1c64\u1c6e\u1c62\u1c74\u1c64" },
-            { "japanese.MonthNames", metaValue_MonthNames },
+            { "generic.AmPmMarkers", metaValue_generic_AmPmMarkers },
+            { "generic.TimePatterns", metaValue_generic_TimePatterns },
+            { "java.time.generic.DatePatterns", metaValue_java_time_generic_DatePatterns },
+            { "generic.DatePatterns", metaValue_generic_DatePatterns },
+            { "generic.DateTimePatterns", metaValue_generic_DateTimePatterns },
+            { "MonthNames", metaValue_MonthNames },
+            { "standalone.MonthNames", metaValue_MonthNames },
+            { "MonthAbbreviations", metaValue_MonthAbbreviations },
+            { "standalone.MonthAbbreviations", metaValue_MonthAbbreviations },
+            { "MonthNarrows", metaValue_MonthNarrows },
+            { "standalone.MonthNarrows", metaValue_MonthNarrows },
+            { "DayNames", metaValue_generic_DayNames },
+            { "standalone.DayNames", metaValue_generic_DayNames },
+            { "DayAbbreviations", metaValue_generic_DayAbbreviations },
             { "standalone.DayAbbreviations", metaValue_generic_DayAbbreviations },
-            { "roc.MonthAbbreviations", metaValue_MonthAbbreviations },
+            { "DayNarrows", metaValue_generic_DayNarrows },
+            { "standalone.DayNarrows", metaValue_generic_DayNarrows },
+            { "QuarterNames", metaValue_generic_QuarterNames },
+            { "standalone.QuarterNames", metaValue_generic_QuarterNames },
+            { "QuarterAbbreviations", metaValue_generic_QuarterNames },
+            { "standalone.QuarterAbbreviations", metaValue_generic_QuarterNames },
+            { "QuarterNarrows", metaValue_generic_QuarterNarrows },
+            { "standalone.QuarterNarrows", metaValue_generic_QuarterNarrows },
+            { "AmPmMarkers", metaValue_generic_AmPmMarkers },
             { "long.Eras", metaValue_long_Eras },
-            { "roc.QuarterNarrows", metaValue_generic_QuarterNarrows },
-            { "islamic.DayNames", metaValue_generic_DayNames },
-            { "buddhist.MonthAbbreviations", metaValue_MonthAbbreviations },
+            { "Eras", metaValue_long_Eras },
+            { "narrow.Eras", metaValue_long_Eras },
+            { "field.era", "\u1c61\u1c69\u1c5c\u1c7d" },
+            { "field.year", "\u1c65\u1c6e\u1c68\u1c62\u1c5f/\u1c75\u1c5a\u1c6a\u1c77\u1c5a\u1c5e\u1c68" },
+            { "field.month", "\u1c6a\u1c5f\u1c78\u1c6b\u1c5a" },
+            { "field.week", "\u1c66\u1c5f\u1c6f\u1c5b\u1c5f/\u1c6e\u1c62\u1c66\u1c5f" },
+            { "field.weekday", "\u1c66\u1c5f\u1c6f\u1c5b\u1c5f \u1c68\u1c6e\u1c6d\u1c5f\u1c5c \u1c62\u1c5f\u1c66\u1c5f" },
+            { "field.dayperiod", "\u1c65\u1c6e\u1c5b\u1c5f\u1c5c/\u1c5f\u1c79\u1c6d\u1c69\u1c75" },
+            { "field.hour", "\u1c74\u1c5f\u1c72\u1c5f\u1c5d" },
+            { "timezone.gmtFormat", "\u1c61\u1c64\u1c6e\u1c62\u1c74\u1c64{0}" },
+            { "timezone.gmtZeroFormat", "\u1c61\u1c64\u1c6e\u1c62\u1c74\u1c64" },
+            { "timezone.regionFormat", "{0} \u1c5a\u1c60\u1c5b\u1c5a" },
+            { "timezone.regionFormat.daylight", "{0} \u1c6b\u1c64\u1c71\u1c75\u1c6e\u1c72\u1c5f \u1c5a\u1c60\u1c5b\u1c5a" },
+            { "timezone.regionFormat.standard", "{0} \u1c62\u1c5f\u1c71\u1c5a\u1c60 \u1c5a\u1c60\u1c5b\u1c5a" },
+            { "field.minute", "\u1c74\u1c64\u1c6f\u1c64\u1c61" },
+            { "field.second", "\u1c74\u1c64\u1c68\u1c64\u1c61" },
+            { "field.zone", "\u1c74\u1c5a\u1c74\u1c77\u1c5f" },
+            { "TimePatterns", metaValue_generic_TimePatterns },
+            { "DatePatterns",
+                new String[] {
+                    "EEEE, d MMMM y",
+                    "d MMMM y",
+                    "d MMM y",
+                    "d/M/yy",
+                }
+            },
             { "DateTimePatterns", metaValue_generic_DateTimePatterns },
+            { "PluralRules", "one:n = 1;two:n = 2" },
             { "buddhist.MonthNames", metaValue_MonthNames },
+            { "buddhist.MonthAbbreviations", metaValue_MonthAbbreviations },
+            { "buddhist.MonthNarrows", metaValue_MonthNarrows },
+            { "buddhist.DayNames", metaValue_generic_DayNames },
+            { "buddhist.DayAbbreviations", metaValue_generic_DayAbbreviations },
+            { "buddhist.DayNarrows", metaValue_generic_DayNarrows },
+            { "buddhist.QuarterNames", metaValue_generic_QuarterNames },
+            { "buddhist.QuarterAbbreviations", metaValue_generic_QuarterNames },
+            { "buddhist.QuarterNarrows", metaValue_generic_QuarterNarrows },
+            { "buddhist.AmPmMarkers", metaValue_generic_AmPmMarkers },
+            { "buddhist.TimePatterns", metaValue_generic_TimePatterns },
+            { "java.time.buddhist.DatePatterns", metaValue_java_time_generic_DatePatterns },
+            { "buddhist.DatePatterns", metaValue_generic_DatePatterns },
+            { "japanese.MonthNames", metaValue_MonthNames },
+            { "japanese.MonthAbbreviations", metaValue_MonthAbbreviations },
+            { "japanese.MonthNarrows", metaValue_MonthNarrows },
+            { "japanese.DayNames", metaValue_generic_DayNames },
+            { "japanese.DayAbbreviations", metaValue_generic_DayAbbreviations },
+            { "japanese.DayNarrows", metaValue_generic_DayNarrows },
+            { "japanese.QuarterNames", metaValue_generic_QuarterNames },
+            { "japanese.QuarterAbbreviations", metaValue_generic_QuarterNames },
+            { "japanese.QuarterNarrows", metaValue_generic_QuarterNarrows },
+            { "japanese.AmPmMarkers", metaValue_generic_AmPmMarkers },
+            { "japanese.TimePatterns", metaValue_generic_TimePatterns },
+            { "java.time.japanese.DatePatterns", metaValue_java_time_generic_DatePatterns },
+            { "japanese.DatePatterns", metaValue_generic_DatePatterns },
+            { "roc.MonthNames", metaValue_MonthNames },
+            { "roc.MonthAbbreviations", metaValue_MonthAbbreviations },
+            { "roc.MonthNarrows", metaValue_MonthNarrows },
+            { "roc.DayNames", metaValue_generic_DayNames },
+            { "roc.DayAbbreviations", metaValue_generic_DayAbbreviations },
+            { "roc.DayNarrows", metaValue_generic_DayNarrows },
+            { "roc.QuarterNames", metaValue_generic_QuarterNames },
+            { "roc.QuarterAbbreviations", metaValue_generic_QuarterNames },
+            { "roc.QuarterNarrows", metaValue_generic_QuarterNarrows },
+            { "roc.AmPmMarkers", metaValue_generic_AmPmMarkers },
+            { "roc.TimePatterns", metaValue_generic_TimePatterns },
+            { "java.time.roc.DatePatterns", metaValue_java_time_generic_DatePatterns },
+            { "roc.DatePatterns", metaValue_generic_DatePatterns },
+            { "islamic.DayNames", metaValue_generic_DayNames },
+            { "islamic.DayAbbreviations", metaValue_generic_DayAbbreviations },
+            { "islamic.DayNarrows", metaValue_generic_DayNarrows },
+            { "islamic.QuarterNames", metaValue_generic_QuarterNames },
+            { "islamic.QuarterAbbreviations", metaValue_generic_QuarterNames },
+            { "islamic.QuarterNarrows", metaValue_generic_QuarterNarrows },
+            { "islamic.AmPmMarkers", metaValue_generic_AmPmMarkers },
+            { "islamic.TimePatterns", metaValue_generic_TimePatterns },
+            { "java.time.islamic.DatePatterns", metaValue_java_time_generic_DatePatterns },
+            { "islamic.DatePatterns", metaValue_generic_DatePatterns },
+            { "calendarname.gregorian", metaValue_calendarname_gregorian },
+            { "calendarname.gregory", metaValue_calendarname_gregorian },
+            { "DefaultNumberingSystem", "olck" },
             { "latn.NumberElements",
                 new String[] {
                     ".",
@@ -236,86 +322,6 @@ public class FormatData_sat extends ListResourceBundle {
                     "",
                 }
             },
-            { "japanese.DatePatterns", metaValue_generic_DatePatterns },
-            { "MonthNarrows", metaValue_MonthNarrows },
-            { "buddhist.DayNames", metaValue_generic_DayNames },
-            { "field.minute", "\u1c74\u1c64\u1c6f\u1c64\u1c61" },
-            { "field.era", "\u1c61\u1c69\u1c5c\u1c7d" },
-            { "buddhist.AmPmMarkers", metaValue_generic_AmPmMarkers },
-            { "field.dayperiod", "\u1c65\u1c6e\u1c5b\u1c5f\u1c5c/\u1c5f\u1c79\u1c6d\u1c69\u1c75" },
-            { "standalone.MonthNarrows", metaValue_MonthNarrows },
-            { "japanese.QuarterNarrows", metaValue_generic_QuarterNarrows },
-            { "islamic.DatePatterns", metaValue_generic_DatePatterns },
-            { "roc.QuarterAbbreviations", metaValue_generic_QuarterNames },
-            { "field.month", "\u1c6a\u1c5f\u1c78\u1c6b\u1c5a" },
-            { "field.second", "\u1c74\u1c64\u1c68\u1c64\u1c61" },
-            { "DayAbbreviations", metaValue_generic_DayAbbreviations },
-            { "DayNarrows", metaValue_generic_DayNarrows },
-            { "roc.DatePatterns", metaValue_generic_DatePatterns },
-            { "java.time.generic.DatePatterns", metaValue_java_time_generic_DatePatterns },
-            { "generic.TimePatterns", metaValue_generic_TimePatterns },
-            { "generic.DayAbbreviations", metaValue_generic_DayAbbreviations },
-            { "buddhist.TimePatterns", metaValue_generic_TimePatterns },
-            { "generic.QuarterAbbreviations", metaValue_generic_QuarterNames },
-            { "standalone.MonthAbbreviations", metaValue_MonthAbbreviations },
-            { "timezone.regionFormat", "{0} \u1c5a\u1c60\u1c5b\u1c5a" },
-            { "buddhist.QuarterNarrows", metaValue_generic_QuarterNarrows },
-            { "standalone.QuarterNames", metaValue_generic_QuarterNames },
-            { "japanese.MonthNarrows", metaValue_MonthNarrows },
-            { "islamic.QuarterAbbreviations", metaValue_generic_QuarterNames },
-            { "roc.DayAbbreviations", metaValue_generic_DayAbbreviations },
-            { "standalone.DayNarrows", metaValue_generic_DayNarrows },
-            { "islamic.AmPmMarkers", metaValue_generic_AmPmMarkers },
-            { "generic.DateTimePatterns", metaValue_generic_DateTimePatterns },
-            { "TimePatterns", metaValue_generic_TimePatterns },
-            { "islamic.DayNarrows", metaValue_generic_DayNarrows },
-            { "field.zone", "\u1c74\u1c5a\u1c74\u1c77\u1c5f" },
-            { "generic.DayNarrows", metaValue_generic_DayNarrows },
-            { "japanese.QuarterAbbreviations", metaValue_generic_QuarterNames },
-            { "Eras", metaValue_long_Eras },
-            { "roc.DayNames", metaValue_generic_DayNames },
-            { "islamic.QuarterNames", metaValue_generic_QuarterNames },
-            { "QuarterNarrows", metaValue_generic_QuarterNarrows },
-            { "standalone.QuarterNarrows", metaValue_generic_QuarterNarrows },
-            { "java.time.islamic.DatePatterns", metaValue_java_time_generic_DatePatterns },
-            { "field.weekday", "\u1c66\u1c5f\u1c6f\u1c5b\u1c5f \u1c68\u1c6e\u1c6d\u1c5f\u1c5c \u1c62\u1c5f\u1c66\u1c5f" },
-            { "japanese.MonthAbbreviations", metaValue_MonthAbbreviations },
-            { "generic.DayNames", metaValue_generic_DayNames },
-            { "islamic.DayAbbreviations", metaValue_generic_DayAbbreviations },
-            { "japanese.QuarterNames", metaValue_generic_QuarterNames },
-            { "buddhist.QuarterAbbreviations", metaValue_generic_QuarterNames },
-            { "japanese.DayNames", metaValue_generic_DayNames },
-            { "japanese.DayAbbreviations", metaValue_generic_DayAbbreviations },
-            { "DayNames", metaValue_generic_DayNames },
-            { "buddhist.DatePatterns", metaValue_generic_DatePatterns },
-            { "roc.MonthNames", metaValue_MonthNames },
-            { "field.week", "\u1c66\u1c5f\u1c6f\u1c5b\u1c5f/\u1c6e\u1c62\u1c66\u1c5f" },
-            { "buddhist.QuarterNames", metaValue_generic_QuarterNames },
-            { "islamic.QuarterNarrows", metaValue_generic_QuarterNarrows },
-            { "buddhist.MonthNarrows", metaValue_MonthNarrows },
-            { "roc.DayNarrows", metaValue_generic_DayNarrows },
-            { "roc.AmPmMarkers", metaValue_generic_AmPmMarkers },
-            { "generic.QuarterNames", metaValue_generic_QuarterNames },
-            { "java.time.buddhist.DatePatterns", metaValue_java_time_generic_DatePatterns },
-            { "java.time.roc.DatePatterns", metaValue_java_time_generic_DatePatterns },
-            { "calendarname.gregorian", metaValue_calendarname_gregorian },
-            { "timezone.regionFormat.daylight", "{0} \u1c6b\u1c64\u1c71\u1c75\u1c6e\u1c72\u1c5f \u1c5a\u1c60\u1c5b\u1c5a" },
-            { "DatePatterns",
-                new String[] {
-                    "EEEE, d MMMM y",
-                    "d MMMM y",
-                    "d MMM y",
-                    "d/M/yy",
-                }
-            },
-            { "buddhist.DayAbbreviations", metaValue_generic_DayAbbreviations },
-            { "islamic.TimePatterns", metaValue_generic_TimePatterns },
-            { "standalone.DayNames", metaValue_generic_DayNames },
-            { "MonthAbbreviations", metaValue_MonthAbbreviations },
-            { "PluralRules", "one:n = 1;two:n = 2" },
-            { "field.hour", "\u1c74\u1c5f\u1c72\u1c5f\u1c5d" },
-            { "generic.AmPmMarkers", metaValue_generic_AmPmMarkers },
-            { "standalone.MonthNames", metaValue_MonthNames },
             { "latn.NumberPatterns",
                 new String[] {
                     "#,##0.###",
@@ -324,12 +330,6 @@ public class FormatData_sat extends ListResourceBundle {
                     "",
                 }
             },
-            { "buddhist.DayNarrows", metaValue_generic_DayNarrows },
-            { "japanese.DayNarrows", metaValue_generic_DayNarrows },
-            { "QuarterNames", metaValue_generic_QuarterNames },
-            { "roc.TimePatterns", metaValue_generic_TimePatterns },
-            { "QuarterAbbreviations", metaValue_generic_QuarterNames },
-            { "calendarname.gregory", metaValue_calendarname_gregorian },
         };
         return data;
     }
