@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -70,192 +66,115 @@ import java.util.ListResourceBundle;
 public class FormatData_yo_BJ extends ListResourceBundle {
     @Override
     protected final Object[][] getContents() {
-        final String[] metaValue_MonthNames = new String[] {
-               "Osh\u00f9 Sh\u025b\u0301r\u025b\u0301",
-               "Osh\u00f9 \u00c8r\u00e8l\u00e8",
-               "Osh\u00f9 \u0190r\u025b\u0300n\u00e0",
-               "Osh\u00f9 \u00ccgb\u00e9",
-               "Osh\u00f9 \u0190\u0300bibi",
-               "Osh\u00f9 \u00d2k\u00fadu",
-               "Osh\u00f9 Ag\u025bm\u0254",
-               "Osh\u00f9 \u00d2g\u00fan",
-               "Osh\u00f9 Owewe",
-               "Osh\u00f9 \u0186\u0300w\u00e0r\u00e0",
-               "Osh\u00f9 B\u00e9l\u00fa",
-               "Osh\u00f9 \u0186\u0300p\u025b\u0300",
-               "",
-            };
-        final String[] metaValue_MonthAbbreviations = new String[] {
-               "Sh\u025b\u0301r",
-               "\u00c8r\u00e8l",
-               "\u0190r\u025b\u0300n",
-               "\u00ccgb",
-               "\u0190\u0300bi",
-               "\u00d2k\u00fa",
-               "Ag\u025b",
-               "\u00d2g\u00fa",
-               "Owe",
-               "\u0186\u0300w\u00e0",
-               "B\u00e9l",
-               "\u0186\u0300p\u025b",
-               "",
-            };
+        final String[] metaValue_generic_AmPmMarkers = new String[] {
+            "\u00c0\u00e1r\u0254\u0300",
+            "\u0186\u0300s\u00e1n",
+            "",
+            "",
+            "",
+            "",
+            "",
+            "",
+            "",
+            "",
+            "",
+            "",
+        };
         final String[] metaValue_MonthNarrows = new String[] {
-               "S",
-               "\u00c8",
-               "\u0190",
-               "\u00cc",
-               "\u0190\u0300",
-               "\u00d2",
-               "A",
-               "\u00d2",
-               "O",
-               "\u0186\u0300",
-               "B",
-               "\u0186\u0300",
-               "",
-            };
-        final String[] metaValue_DayNames = new String[] {
-               "\u0186j\u0254\u0301 \u00c0\u00eck\u00fa",
-               "\u0186j\u0254\u0301 Aj\u00e9",
-               "\u0186j\u0254\u0301 \u00ccs\u025b\u0301gun",
-               "\u0186j\u0254\u0301r\u00fa",
-               "\u0186j\u0254\u0301b\u0254",
-               "\u0186j\u0254\u0301 \u0190t\u00ec",
-               "\u0186j\u0254\u0301 \u00c0b\u00e1m\u025b\u0301ta",
-            };
-        final String[] metaValue_DayAbbreviations = new String[] {
-               "\u00c0\u00eck",
-               "Aj",
-               "\u00ccs\u025b\u0301g",
-               "\u0186j\u0254\u0301r",
-               "\u0186j\u0254\u0301b",
-               "\u0190t",
-               "\u00c0b\u00e1m",
-            };
-        final String[] metaValue_DayNarrows = new String[] {
-               "\u00c0",
-               "A",
-               "\u00cc",
-               "\u0186",
-               "\u0186",
-               "\u0190",
-               "\u00c0",
-            };
-        final String[] metaValue_QuarterNames = new String[] {
-               "\u00ccd\u00e1m\u025b\u0301rin k\u00edn\u00ed",
-               "\u00ccd\u00e1m\u025b\u0301rin Kej\u00ec",
-               "\u00ccd\u00e1m\u025b\u0301rin K\u025bta",
-               "\u00ccd\u00e1m\u025b\u0301rin K\u025brin",
-            };
-        final String[] metaValue_QuarterNarrows = new String[] {
-               "k\u00edn\u00ed",
-               "Kej\u00ec",
-               "K\u025bta",
-               "K\u025bin",
-            };
-        final String[] metaValue_AmPmMarkers = new String[] {
-               "\u00c0\u00e1r\u0254\u0300",
-               "\u0186\u0300s\u00e1n",
-            };
+            "S",
+            "\u00c8",
+            "\u0190",
+            "\u00cc",
+            "\u0190\u0300",
+            "\u00d2",
+            "A",
+            "\u00d2",
+            "O",
+            "\u0186\u0300",
+            "B",
+            "\u0186\u0300",
+            "",
+        };
+        final String[] metaValue_generic_DayNames = new String[] {
+            "\u0186j\u0254\u0301 \u00c0\u00eck\u00fa",
+            "\u0186j\u0254\u0301 Aj\u00e9",
+            "\u0186j\u0254\u0301 \u00ccs\u025b\u0301gun",
+            "\u0186j\u0254\u0301r\u00fa",
+            "\u0186j\u0254\u0301b\u0254",
+            "\u0186j\u0254\u0301 \u0190t\u00ec",
+            "\u0186j\u0254\u0301 \u00c0b\u00e1m\u025b\u0301ta",
+        };
+        final String[] metaValue_generic_DayAbbreviations = new String[] {
+            "\u00c0\u00eck",
+            "Aj",
+            "\u00ccs\u025b\u0301g",
+            "\u0186j\u0254\u0301r",
+            "\u0186j\u0254\u0301b",
+            "\u0190t",
+            "\u00c0b\u00e1m",
+        };
+        final String[] metaValue_generic_DayNarrows = new String[] {
+            "\u00c0",
+            "A",
+            "\u00cc",
+            "\u0186",
+            "\u0186",
+            "\u0190",
+            "\u00c0",
+        };
+        final String[] metaValue_generic_QuarterNames = new String[] {
+            "\u00ccd\u00e1m\u025b\u0301rin k\u00edn\u00ed",
+            "\u00ccd\u00e1m\u025b\u0301rin Kej\u00ec",
+            "\u00ccd\u00e1m\u025b\u0301rin K\u025bta",
+            "\u00ccd\u00e1m\u025b\u0301rin K\u025brin",
+        };
+        final String[] metaValue_generic_QuarterNarrows = new String[] {
+            "k\u00edn\u00ed",
+            "Kej\u00ec",
+            "K\u025bta",
+            "K\u025bin",
+        };
+        final String[] metaValue_MonthNames = new String[] {
+            "Osh\u00f9 Sh\u025b\u0301r\u025b\u0301",
+            "Osh\u00f9 \u00c8r\u00e8l\u00e8",
+            "Osh\u00f9 \u0190r\u025b\u0300n\u00e0",
+            "Osh\u00f9 \u00ccgb\u00e9",
+            "Osh\u00f9 \u0190\u0300bibi",
+            "Osh\u00f9 \u00d2k\u00fadu",
+            "Osh\u00f9 Ag\u025bm\u0254",
+            "Osh\u00f9 \u00d2g\u00fan",
+            "Osh\u00f9 Owewe",
+            "Osh\u00f9 \u0186\u0300w\u00e0r\u00e0",
+            "Osh\u00f9 B\u00e9l\u00fa",
+            "Osh\u00f9 \u0186\u0300p\u025b\u0300",
+            "",
+        };
+        final String[] metaValue_MonthAbbreviations = new String[] {
+            "Sh\u025b\u0301r",
+            "\u00c8r\u00e8l",
+            "\u0190r\u025b\u0300n",
+            "\u00ccgb",
+            "\u0190\u0300bi",
+            "\u00d2k\u00fa",
+            "Ag\u025b",
+            "\u00d2g\u00fa",
+            "Owe",
+            "\u0186\u0300w\u00e0",
+            "B\u00e9l",
+            "\u0186\u0300p\u025b",
+            "",
+        };
         final String metaValue_calendarname_gregorian = "K\u00e0l\u025b\u0301\u0144d\u00e0 Gregory";
         final Object[][] data = new Object[][] {
+            { "generic.DayNames", metaValue_generic_DayNames },
+            { "generic.DayAbbreviations", metaValue_generic_DayAbbreviations },
+            { "generic.DayNarrows", metaValue_generic_DayNarrows },
+            { "generic.QuarterNames", metaValue_generic_QuarterNames },
+            { "generic.QuarterNarrows", metaValue_generic_QuarterNarrows },
+            { "generic.AmPmMarkers", metaValue_generic_AmPmMarkers },
+            { "generic.narrow.AmPmMarkers", metaValue_generic_AmPmMarkers },
+            { "generic.abbreviated.AmPmMarkers", metaValue_generic_AmPmMarkers },
             { "MonthNames", metaValue_MonthNames },
-            { "field.year", "\u0186d\u00fan" },
-            { "roc.DayAbbreviations", metaValue_DayAbbreviations },
-            { "standalone.DayNarrows", metaValue_DayNarrows },
-            { "japanese.AmPmMarkers", metaValue_AmPmMarkers },
-            { "islamic.AmPmMarkers", metaValue_AmPmMarkers },
-            { "AmPmMarkers", metaValue_AmPmMarkers },
-            { "roc.QuarterNames", metaValue_QuarterNames },
-            { "islamic.DayNarrows", metaValue_DayNarrows },
-            { "roc.MonthNarrows", metaValue_MonthNarrows },
-            { "islamic.narrow.AmPmMarkers", metaValue_AmPmMarkers },
-            { "abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
-            { "japanese.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
-            { "calendarname.japanese", "K\u00e0l\u025b\u0300\u0144d\u00e0 ti J\u00e0p\u00e1n\u00f9" },
-            { "buddhist.narrow.AmPmMarkers", metaValue_AmPmMarkers },
-            { "buddhist.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
-            { "japanese.MonthNames", metaValue_MonthNames },
-            { "roc.DayNames", metaValue_DayNames },
-            { "standalone.DayAbbreviations", metaValue_DayAbbreviations },
-            { "roc.MonthAbbreviations", metaValue_MonthAbbreviations },
-            { "islamic.QuarterNames", metaValue_QuarterNames },
-            { "QuarterNarrows", metaValue_QuarterNarrows },
-            { "islamic.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
-            { "standalone.QuarterNarrows",
-                new String[] {
-                    "k\u00ed",
-                    "Ke",
-                    "K\u025bt",
-                    "K\u025br",
-                }
-            },
-            { "roc.QuarterNarrows", metaValue_QuarterNarrows },
-            { "islamic.DayNames", metaValue_DayNames },
-            { "buddhist.MonthAbbreviations", metaValue_MonthAbbreviations },
-            { "field.weekday", "\u0186j\u0254\u0301 t\u00f3 w\u00e0 l\u00e1\u00e0\u00e1r\u00edn \u0254\u0300s\u025b\u0300" },
-            { "buddhist.MonthNames", metaValue_MonthNames },
-            { "narrow.AmPmMarkers", metaValue_AmPmMarkers },
-            { "latn.NumberElements",
-                new String[] {
-                    ".",
-                    ",",
-                    ";",
-                    "%",
-                    "0",
-                    "#",
-                    "-",
-                    "E",
-                    "\u2030",
-                    "\u221e",
-                    "NaN",
-                    "",
-                    "",
-                }
-            },
-            { "MonthNarrows", metaValue_MonthNarrows },
-            { "japanese.MonthAbbreviations", metaValue_MonthAbbreviations },
-            { "buddhist.DayNames", metaValue_DayNames },
-            { "field.minute", "\u00ccs\u025b\u0301j\u00fa" },
-            { "islamic.DayAbbreviations", metaValue_DayAbbreviations },
-            { "buddhist.AmPmMarkers", metaValue_AmPmMarkers },
-            { "field.dayperiod", "\u00c0\u00e1r\u0254\u0300/\u0254\u0300s\u00e1n" },
-            { "standalone.MonthNarrows", metaValue_MonthNarrows },
-            { "japanese.QuarterNames", metaValue_QuarterNames },
-            { "japanese.QuarterNarrows", metaValue_QuarterNarrows },
-            { "calendarname.roc", "K\u00e0l\u025b\u0300\u0144d\u00e0 Minguo" },
-            { "japanese.DayNames", metaValue_DayNames },
-            { "japanese.DayAbbreviations", metaValue_DayAbbreviations },
-            { "DayNames", metaValue_DayNames },
-            { "field.second", "\u00ccs\u025b\u0301j\u00fa \u00c0\u00e0y\u00e1" },
-            { "roc.MonthNames", metaValue_MonthNames },
-            { "field.week", "\u0186\u0300s\u025b\u0300" },
-            { "DayAbbreviations", metaValue_DayAbbreviations },
-            { "DayNarrows", metaValue_DayNarrows },
-            { "buddhist.MonthNarrows", metaValue_MonthNarrows },
-            { "buddhist.QuarterNames", metaValue_QuarterNames },
-            { "islamic.QuarterNarrows", metaValue_QuarterNarrows },
-            { "calendarname.islamic", "K\u00e0l\u025b\u0300\u0144d\u00e0 L\u00e1r\u00fab\u00e1w\u00e1" },
-            { "roc.DayNarrows", metaValue_DayNarrows },
-            { "roc.AmPmMarkers", metaValue_AmPmMarkers },
-            { "calendarname.gregorian", metaValue_calendarname_gregorian },
-            { "timezone.regionFormat.daylight", "{0} \u00c0k\u00f3k\u00f2 oj\u00fam\u0254m\u0254" },
-            { "buddhist.DayAbbreviations", metaValue_DayAbbreviations },
-            { "MonthAbbreviations", metaValue_MonthAbbreviations },
-            { "standalone.DayNames",
-                new String[] {
-                    "\u00c0\u00eck\u00fa",
-                    "Aj\u00e9",
-                    "\u00ccs\u025b\u0301gun",
-                    "\u0186j\u0254\u0301r\u00fa",
-                    "\u0186j\u0254\u0301b\u0254",
-                    "\u0190t\u00ec",
-                    "\u00c0b\u00e1m\u025b\u0301ta",
-                }
-            },
-            { "japanese.narrow.AmPmMarkers", metaValue_AmPmMarkers },
-            { "calendarname.buddhist", "K\u00e0l\u025b\u0300\u0144d\u00e0 Buddhist" },
             { "standalone.MonthNames",
                 new String[] {
                     "Sh\u025b\u0301r\u025b\u0301",
@@ -273,6 +192,7 @@ public class FormatData_yo_BJ extends ListResourceBundle {
                     "",
                 }
             },
+            { "MonthAbbreviations", metaValue_MonthAbbreviations },
             { "standalone.MonthAbbreviations",
                 new String[] {
                     "Sh\u025b\u0301",
@@ -290,6 +210,112 @@ public class FormatData_yo_BJ extends ListResourceBundle {
                     "",
                 }
             },
+            { "MonthNarrows", metaValue_MonthNarrows },
+            { "standalone.MonthNarrows", metaValue_MonthNarrows },
+            { "DayNames", metaValue_generic_DayNames },
+            { "standalone.DayNames",
+                new String[] {
+                    "\u00c0\u00eck\u00fa",
+                    "Aj\u00e9",
+                    "\u00ccs\u025b\u0301gun",
+                    "\u0186j\u0254\u0301r\u00fa",
+                    "\u0186j\u0254\u0301b\u0254",
+                    "\u0190t\u00ec",
+                    "\u00c0b\u00e1m\u025b\u0301ta",
+                }
+            },
+            { "DayAbbreviations", metaValue_generic_DayAbbreviations },
+            { "standalone.DayAbbreviations", metaValue_generic_DayAbbreviations },
+            { "DayNarrows", metaValue_generic_DayNarrows },
+            { "standalone.DayNarrows", metaValue_generic_DayNarrows },
+            { "QuarterNames", metaValue_generic_QuarterNames },
+            { "standalone.QuarterNames", metaValue_generic_QuarterNames },
+            { "QuarterAbbreviations", metaValue_generic_QuarterNames },
+            { "QuarterNarrows", metaValue_generic_QuarterNarrows },
+            { "standalone.QuarterNarrows",
+                new String[] {
+                    "k\u00ed",
+                    "Ke",
+                    "K\u025bt",
+                    "K\u025br",
+                }
+            },
+            { "AmPmMarkers", metaValue_generic_AmPmMarkers },
+            { "narrow.AmPmMarkers", metaValue_generic_AmPmMarkers },
+            { "abbreviated.AmPmMarkers", metaValue_generic_AmPmMarkers },
+            { "field.year", "\u0186d\u00fan" },
+            { "field.week", "\u0186\u0300s\u025b\u0300" },
+            { "field.weekday", "\u0186j\u0254\u0301 t\u00f3 w\u00e0 l\u00e1\u00e0\u00e1r\u00edn \u0254\u0300s\u025b\u0300" },
+            { "field.dayperiod", "\u00c0\u00e1r\u0254\u0300/\u0254\u0300s\u00e1n" },
+            { "timezone.regionFormat.daylight", "{0} \u00c0k\u00f3k\u00f2 oj\u00fam\u0254m\u0254" },
+            { "field.minute", "\u00ccs\u025b\u0301j\u00fa" },
+            { "field.second", "\u00ccs\u025b\u0301j\u00fa \u00c0\u00e0y\u00e1" },
+            { "buddhist.MonthNames", metaValue_MonthNames },
+            { "buddhist.MonthAbbreviations", metaValue_MonthAbbreviations },
+            { "buddhist.MonthNarrows", metaValue_MonthNarrows },
+            { "buddhist.DayNames", metaValue_generic_DayNames },
+            { "buddhist.DayAbbreviations", metaValue_generic_DayAbbreviations },
+            { "buddhist.DayNarrows", metaValue_generic_DayNarrows },
+            { "buddhist.QuarterNames", metaValue_generic_QuarterNames },
+            { "buddhist.QuarterNarrows", metaValue_generic_QuarterNarrows },
+            { "buddhist.AmPmMarkers", metaValue_generic_AmPmMarkers },
+            { "buddhist.narrow.AmPmMarkers", metaValue_generic_AmPmMarkers },
+            { "buddhist.abbreviated.AmPmMarkers", metaValue_generic_AmPmMarkers },
+            { "japanese.MonthNames", metaValue_MonthNames },
+            { "japanese.MonthAbbreviations", metaValue_MonthAbbreviations },
+            { "japanese.MonthNarrows", metaValue_MonthNarrows },
+            { "japanese.DayNames", metaValue_generic_DayNames },
+            { "japanese.DayAbbreviations", metaValue_generic_DayAbbreviations },
+            { "japanese.DayNarrows", metaValue_generic_DayNarrows },
+            { "japanese.QuarterNames", metaValue_generic_QuarterNames },
+            { "japanese.QuarterNarrows", metaValue_generic_QuarterNarrows },
+            { "japanese.AmPmMarkers", metaValue_generic_AmPmMarkers },
+            { "japanese.narrow.AmPmMarkers", metaValue_generic_AmPmMarkers },
+            { "japanese.abbreviated.AmPmMarkers", metaValue_generic_AmPmMarkers },
+            { "roc.MonthNames", metaValue_MonthNames },
+            { "roc.MonthAbbreviations", metaValue_MonthAbbreviations },
+            { "roc.MonthNarrows", metaValue_MonthNarrows },
+            { "roc.DayNames", metaValue_generic_DayNames },
+            { "roc.DayAbbreviations", metaValue_generic_DayAbbreviations },
+            { "roc.DayNarrows", metaValue_generic_DayNarrows },
+            { "roc.QuarterNames", metaValue_generic_QuarterNames },
+            { "roc.QuarterNarrows", metaValue_generic_QuarterNarrows },
+            { "roc.AmPmMarkers", metaValue_generic_AmPmMarkers },
+            { "roc.narrow.AmPmMarkers", metaValue_generic_AmPmMarkers },
+            { "roc.abbreviated.AmPmMarkers", metaValue_generic_AmPmMarkers },
+            { "islamic.DayNames", metaValue_generic_DayNames },
+            { "islamic.DayAbbreviations", metaValue_generic_DayAbbreviations },
+            { "islamic.DayNarrows", metaValue_generic_DayNarrows },
+            { "islamic.QuarterNames", metaValue_generic_QuarterNames },
+            { "islamic.QuarterNarrows", metaValue_generic_QuarterNarrows },
+            { "islamic.AmPmMarkers", metaValue_generic_AmPmMarkers },
+            { "islamic.narrow.AmPmMarkers", metaValue_generic_AmPmMarkers },
+            { "islamic.abbreviated.AmPmMarkers", metaValue_generic_AmPmMarkers },
+            { "calendarname.buddhist", "K\u00e0l\u025b\u0301\u0144d\u00e0 Buddhist" },
+            { "calendarname.japanese", "K\u00e0l\u025b\u0301\u0144d\u00e0 ti J\u00e0p\u00e1n\u00f9" },
+            { "calendarname.islamic-civil", "K\u00e0l\u025b\u0301\u0144d\u00e0 ti Musulumi" },
+            { "calendarname.islamic", "K\u00e0l\u025b\u0301\u0144d\u00e0 L\u00e1r\u00fab\u00e1w\u00e1" },
+            { "calendarname.islamic-umalqura", "K\u00e0l\u025b\u0301\u0144d\u00e0 Musulumi" },
+            { "calendarname.gregorian", metaValue_calendarname_gregorian },
+            { "calendarname.gregory", metaValue_calendarname_gregorian },
+            { "calendarname.roc", "K\u00e0l\u025b\u0301\u0144d\u00e0 Minguo" },
+            { "latn.NumberElements",
+                new String[] {
+                    ".",
+                    ",",
+                    ";",
+                    "%",
+                    "0",
+                    "#",
+                    "-",
+                    "E",
+                    "\u2030",
+                    "\u221e",
+                    "NaN",
+                    "",
+                    "",
+                }
+            },
             { "latn.NumberPatterns",
                 new String[] {
                     "#,##0.###",
@@ -317,23 +343,6 @@ public class FormatData_yo_BJ extends ListResourceBundle {
                     "{other:000' 'tirili\u0254\u0300n\u00f9}",
                 }
             },
-            { "buddhist.DayNarrows", metaValue_DayNarrows },
-            { "buddhist.QuarterNarrows", metaValue_QuarterNarrows },
-            { "roc.narrow.AmPmMarkers", metaValue_AmPmMarkers },
-            { "japanese.DayNarrows", metaValue_DayNarrows },
-            { "QuarterNames", metaValue_QuarterNames },
-            { "QuarterAbbreviations", metaValue_QuarterNames },
-            { "standalone.QuarterNames",
-                new String[] {
-                    "\u00ccd\u00e1m\u1eb9\u0301rin k\u00edn\u00ed",
-                    "\u00ccd\u00e1m\u1eb9\u0301rin Kej\u00ec",
-                    "\u00ccd\u00e1m\u025b\u0301rin K\u025bta",
-                    "\u00ccd\u00e1m\u1eb9\u0301rin K\u1eb9rin",
-                }
-            },
-            { "japanese.MonthNarrows", metaValue_MonthNarrows },
-            { "roc.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
-            { "calendarname.gregory", metaValue_calendarname_gregorian },
         };
         return data;
     }
