@@ -31,62 +31,70 @@ import sun.util.locale.provider.LocaleDataMetaInfo;
 import sun.util.locale.provider.LocaleProviderAdapter;
 
 public class CLDRBaseLocaleDataMetaInfo implements LocaleDataMetaInfo {
-    private static final Map<String, String> resourceNameToLocales = new HashMap<>();
-    private static final Map<Locale, String[]> parentLocalesMap = new HashMap<>();
-    private static final Map<String, String> languageAliasMap = new HashMap<>();
+    private static final Map<String, String> resourceNameToLocales = HashMap.newHashMap(1);
+    private static final Map<Locale, String[]> parentLocalesMap = HashMap.newHashMap(9);
+    private static final Map<String, String> languageAliasMap = HashMap.newHashMap(208);
 
     static {
+        parentLocalesMap.put(Locale.forLanguageTag("fr-HT"),
+            new String[] {
+                "", "ht", 
+            });
         resourceNameToLocales.put("AvailableLocales",
-              " en en-Latn-US en-US en-US-POSIX");
+            " en en-Latn-US en-US en-US-POSIX");
         parentLocalesMap.put(Locale.forLanguageTag("es-419"),
-             new String[] {
-                 "", "es-AR", "es-BO", "es-BR", "es-BZ", "es-CL", "es-CO", "es-CR", 
-                 "es-CU", "es-DO", "es-EC", "es-GT", "es-HN", "es-MX", "es-NI", "es-PA", 
-                 "es-PE", "es-PR", "es-PY", "es-SV", "es-US", "es-UY", "es-VE", 
-             });
+            new String[] {
+                "", "es-AR", "es-BO", "es-BR", "es-BZ", "es-CL", "es-CO", "es-CR", 
+                "es-CU", "es-DO", "es-EC", "es-GT", "es-HN", "es-MX", "es-NI", "es-PA", 
+                "es-PE", "es-PR", "es-PY", "es-SV", "es-US", "es-UY", "es-VE", 
+            });
         parentLocalesMap.put(Locale.ROOT,
-             new String[] {
-                 "", "az-Arab", "az-Cyrl", "blt-Latn", "bm-Nkoo", "bs-Cyrl", "byn-Latn", 
-                 "cu-Glag", "dje-Arab", "dyo-Arab", "en-Dsrt", "en-Shaw", "ff-Adlm", 
-                 "ff-Arab", "ha-Arab", "hi-Latn", "iu-Latn", "kk-Arab", "ks-Deva", 
-                 "ku-Arab", "ky-Arab", "ky-Latn", "ml-Arab", "mn-Mong", "mni-Mtei", 
-                 "ms-Arab", "pa-Arab", "sat-Deva", "sd-Deva", "sd-Khoj", "sd-Sind", 
-                 "shi-Latn", "so-Arab", "sr-Latn", "sw-Arab", "tg-Arab", "ug-Cyrl", 
-                 "uz-Arab", "uz-Cyrl", "vai-Latn", "wo-Arab", "yo-Arab", "yue-Hans", 
-                 "zh-Hant", 
-             });
+            new String[] {
+                "", "az-Arab", "az-Cyrl", "bal-Latn", "blt-Latn", "bm-Nkoo", "bs-Cyrl", 
+                "byn-Latn", "cu-Glag", "dje-Arab", "dyo-Arab", "en-Dsrt", "en-Shaw", 
+                "ff-Adlm", "ff-Arab", "ha-Arab", "iu-Latn", "kk-Arab", "ks-Deva", 
+                "ku-Arab", "ky-Arab", "ky-Latn", "ml-Arab", "mn-Mong", "mni-Mtei", 
+                "ms-Arab", "pa-Arab", "sat-Deva", "sd-Deva", "sd-Khoj", "sd-Sind", 
+                "shi-Latn", "so-Arab", "sr-Latn", "sw-Arab", "tg-Arab", "ug-Cyrl", 
+                "uz-Arab", "uz-Cyrl", "vai-Latn", "wo-Arab", "yo-Arab", "yue-Hans", 
+                "zh-Hant", 
+            });
         parentLocalesMap.put(Locale.forLanguageTag("zh-Hant-HK"),
-             new String[] {
-                 "", "zh-Hant-MO", 
-             });
+            new String[] {
+                "", "zh-Hant-MO", 
+            });
         parentLocalesMap.put(Locale.forLanguageTag("en-001"),
-             new String[] {
-                 "", "en-150", "en-AG", "en-AI", "en-AU", "en-BB", "en-BM", "en-BS", 
-                 "en-BW", "en-BZ", "en-CA", "en-CC", "en-CK", "en-CM", "en-CX", "en-CY", 
-                 "en-DG", "en-DM", "en-ER", "en-FJ", "en-FK", "en-FM", "en-GB", "en-GD", 
-                 "en-GG", "en-GH", "en-GI", "en-GM", "en-GY", "en-HK", "en-IE", "en-IL", 
-                 "en-IM", "en-IN", "en-IO", "en-JE", "en-JM", "en-KE", "en-KI", "en-KN", 
-                 "en-KY", "en-LC", "en-LR", "en-LS", "en-MG", "en-MO", "en-MS", "en-MT", 
-                 "en-MU", "en-MW", "en-MY", "en-NA", "en-NF", "en-NG", "en-NR", "en-NU", 
-                 "en-NZ", "en-PG", "en-PH", "en-PK", "en-PN", "en-PW", "en-RW", "en-SB", 
-                 "en-SC", "en-SD", "en-SG", "en-SH", "en-SL", "en-SS", "en-SX", "en-SZ", 
-                 "en-TC", "en-TK", "en-TO", "en-TT", "en-TV", "en-TZ", "en-UG", "en-VC", 
-                 "en-VG", "en-VU", "en-WS", "en-ZA", "en-ZM", "en-ZW", 
-             });
+            new String[] {
+                "", "en-150", "en-AG", "en-AI", "en-AU", "en-BB", "en-BM", "en-BS", 
+                "en-BW", "en-BZ", "en-CC", "en-CK", "en-CM", "en-CX", "en-CY", "en-DG", 
+                "en-DM", "en-ER", "en-FJ", "en-FK", "en-FM", "en-GB", "en-GD", "en-GG", 
+                "en-GH", "en-GI", "en-GM", "en-GY", "en-HK", "en-IE", "en-IL", "en-IM", 
+                "en-IN", "en-IO", "en-JE", "en-JM", "en-KE", "en-KI", "en-KN", "en-KY", 
+                "en-LC", "en-LR", "en-LS", "en-MG", "en-MO", "en-MS", "en-MT", "en-MU", 
+                "en-MV", "en-MW", "en-MY", "en-NA", "en-NF", "en-NG", "en-NR", "en-NU", 
+                "en-NZ", "en-PG", "en-PK", "en-PN", "en-PW", "en-RW", "en-SB", "en-SC", 
+                "en-SD", "en-SG", "en-SH", "en-SL", "en-SS", "en-SX", "en-SZ", "en-TC", 
+                "en-TK", "en-TO", "en-TT", "en-TV", "en-TZ", "en-UG", "en-VC", "en-VG", 
+                "en-VU", "en-WS", "en-ZA", "en-ZM", "en-ZW", 
+            });
         parentLocalesMap.put(Locale.forLanguageTag("pt-PT"),
-             new String[] {
-                 "", "pt-AO", "pt-CH", "pt-CV", "pt-FR", "pt-GQ", "pt-GW", "pt-LU", 
-                 "pt-MO", "pt-MZ", "pt-ST", "pt-TL", 
-             });
+            new String[] {
+                "", "pt-AO", "pt-CH", "pt-CV", "pt-FR", "pt-GQ", "pt-GW", "pt-LU", 
+                "pt-MO", "pt-MZ", "pt-ST", "pt-TL", 
+            });
         parentLocalesMap.put(Locale.forLanguageTag("no"),
-             new String[] {
-                 "", "nb", "nn", 
-             });
+            new String[] {
+                "", "nb", "nn", 
+            });
+        parentLocalesMap.put(Locale.forLanguageTag("en-IN"),
+            new String[] {
+                "", "hi-Latn", 
+            });
         parentLocalesMap.put(Locale.forLanguageTag("en-150"),
-             new String[] {
-                 "", "en-AT", "en-BE", "en-CH", "en-DE", "en-DK", "en-FI", "en-NL", 
-                 "en-SE", "en-SI", 
-             });
+            new String[] {
+                "", "en-AT", "en-BE", "en-CH", "en-DE", "en-DK", "en-FI", "en-NL", 
+                "en-SE", "en-SI", 
+            });
         languageAliasMap.put("zh-cmn-Hant", "zh-Hant");
         languageAliasMap.put("mwj", "vaj");
         languageAliasMap.put("zh-cmn-Hans", "zh-Hans");
@@ -157,6 +165,7 @@ public class CLDRBaseLocaleDataMetaInfo implements LocaleDataMetaInfo {
         languageAliasMap.put("kxe", "tvd");
         languageAliasMap.put("sgl", "isk");
         languageAliasMap.put("kxl", "kru");
+        languageAliasMap.put("pat", "kxr");
         languageAliasMap.put("djl", "dze");
         languageAliasMap.put("elp", "amq");
         languageAliasMap.put("hrr", "jal");
@@ -195,6 +204,7 @@ public class CLDRBaseLocaleDataMetaInfo implements LocaleDataMetaInfo {
         languageAliasMap.put("unp", "wro");
         languageAliasMap.put("aa-saaho", "ssy");
         languageAliasMap.put("cka", "cmr");
+        languageAliasMap.put("bic", "bir");
         languageAliasMap.put("tlw", "weo");
         languageAliasMap.put("und-hepburn-heploc", "und-alalc97");
         languageAliasMap.put("mof", "xnt");
@@ -230,12 +240,16 @@ public class CLDRBaseLocaleDataMetaInfo implements LocaleDataMetaInfo {
         languageAliasMap.put("guv", "duz");
         languageAliasMap.put("oun", "vaj");
         languageAliasMap.put("ais", "ami");
+        languageAliasMap.put("smd", "kmb");
         languageAliasMap.put("jw", "jv");
         languageAliasMap.put("und-aaland", "und-AX");
         languageAliasMap.put("izi", "eza");
         languageAliasMap.put("ncp", "kdz");
+        languageAliasMap.put("blg", "iba");
+        languageAliasMap.put("snb", "iba");
         languageAliasMap.put("cnr", "sr-ME");
         languageAliasMap.put("yiy", "yrm");
+        languageAliasMap.put("ajt", "aeb");
         languageAliasMap.put("nts", "pij");
         languageAliasMap.put("art-lojban", "jbo");
         languageAliasMap.put("und-lojban", "und");
@@ -255,6 +269,7 @@ public class CLDRBaseLocaleDataMetaInfo implements LocaleDataMetaInfo {
         languageAliasMap.put("ggr", "gtu");
         languageAliasMap.put("i-tay", "tay");
         languageAliasMap.put("rmr", "emx");
+        languageAliasMap.put("lak", "ksp");
         languageAliasMap.put("drh", "mn");
         languageAliasMap.put("mo", "ro");
         languageAliasMap.put("drr", "kzk");
@@ -291,7 +306,7 @@ public class CLDRBaseLocaleDataMetaInfo implements LocaleDataMetaInfo {
     }
 
     private static class TZCanonicalIDMapHolder {
-        static final Map<String, String> tzCanonicalIDMap = new HashMap<>(600);
+        static final Map<String, String> tzCanonicalIDMap = HashMap.newHashMap(461);
         static {
             tzCanonicalIDMap.put("fmksa", "Pacific/Kosrae");
             tzCanonicalIDMap.put("ruyks", "Asia/Yakutsk");
@@ -469,10 +484,12 @@ public class CLDRBaseLocaleDataMetaInfo implements LocaleDataMetaInfo {
             tzCanonicalIDMap.put("GB-Eire", "Europe/London");
             tzCanonicalIDMap.put("gwoxb", "Africa/Bissau");
             tzCanonicalIDMap.put("kipho", "Pacific/Enderbury");
+            tzCanonicalIDMap.put("Pacific/Kanton", "Pacific/Enderbury");
             tzCanonicalIDMap.put("ttpos", "America/Port_of_Spain");
             tzCanonicalIDMap.put("ommct", "Asia/Muscat");
             tzCanonicalIDMap.put("lrmlw", "Africa/Monrovia");
             tzCanonicalIDMap.put("imdgs", "Europe/Isle_of_Man");
+            tzCanonicalIDMap.put("mxcjs", "America/Ciudad_Juarez");
             tzCanonicalIDMap.put("npktm", "Asia/Katmandu");
             tzCanonicalIDMap.put("Asia/Kathmandu", "Asia/Katmandu");
             tzCanonicalIDMap.put("robuh", "Europe/Bucharest");
@@ -529,7 +546,6 @@ public class CLDRBaseLocaleDataMetaInfo implements LocaleDataMetaInfo {
             tzCanonicalIDMap.put("dmdom", "America/Dominica");
             tzCanonicalIDMap.put("mtmla", "Europe/Malta");
             tzCanonicalIDMap.put("idjkt", "Asia/Jakarta");
-            tzCanonicalIDMap.put("gaza", "Asia/Gaza");
             tzCanonicalIDMap.put("mwblz", "Africa/Blantyre");
             tzCanonicalIDMap.put("msmni", "America/Montserrat");
             tzCanonicalIDMap.put("pyasu", "America/Asuncion");
@@ -573,6 +589,7 @@ public class CLDRBaseLocaleDataMetaInfo implements LocaleDataMetaInfo {
             tzCanonicalIDMap.put("braux", "America/Araguaina");
             tzCanonicalIDMap.put("nrinu", "Pacific/Nauru");
             tzCanonicalIDMap.put("ugkla", "Africa/Kampala");
+            tzCanonicalIDMap.put("gazastrp", "Asia/Gaza");
             tzCanonicalIDMap.put("zajnb", "Africa/Johannesburg");
             tzCanonicalIDMap.put("cayzs", "America/Coral_Harbour");
             tzCanonicalIDMap.put("America/Atikokan", "America/Coral_Harbour");
@@ -625,6 +642,7 @@ public class CLDRBaseLocaleDataMetaInfo implements LocaleDataMetaInfo {
             tzCanonicalIDMap.put("bymsq", "Europe/Minsk");
             tzCanonicalIDMap.put("aqplm", "Antarctica/Palmer");
             tzCanonicalIDMap.put("uaiev", "Europe/Kiev");
+            tzCanonicalIDMap.put("Europe/Kyiv", "Europe/Kiev");
             tzCanonicalIDMap.put("kmyva", "Indian/Comoro");
             tzCanonicalIDMap.put("rutof", "Asia/Tomsk");
             tzCanonicalIDMap.put("egcai", "Africa/Cairo");
@@ -896,7 +914,7 @@ public class CLDRBaseLocaleDataMetaInfo implements LocaleDataMetaInfo {
     public String availableLanguageTags(String category) {
         return resourceNameToLocales.getOrDefault(category, "");
     }
-
+    
     @Override
     public Map<String, String> getLanguageAliasMap() {
         return languageAliasMap;
@@ -910,4 +928,5 @@ public class CLDRBaseLocaleDataMetaInfo implements LocaleDataMetaInfo {
     public Map<Locale, String[]> parentLocales() {
         return parentLocalesMap;
     }
-}
\ No newline at end of file
+
+}
