@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -106,7 +102,6 @@ public class CurrencyNames_fr_CA extends OpenListResourceBundle {
             { "XPF", "XPF" },
             { "azn", "manat azerba\u00efdjanais" },
             { "cve", "escudo cap-verdien" },
-            { "fkp", "livre des \u00celes Malouines" },
             { "irr", "rial iranien" },
             { "lak", "kip laotien" },
             { "omr", "rial omanais" },
@@ -116,7 +111,6 @@ public class CurrencyNames_fr_CA extends OpenListResourceBundle {
             { "sar", "rial saoudien" },
             { "srd", "dollar du Suriname" },
             { "top", "pa\u2019anga" },
-            { "ttd", "dollar de Trinit\u00e9-et-Tobago" },
             { "vuv", "vatu" },
             { "wst", "tala" },
             { "xxx", "Devise inconnue" },
