@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -398,7 +394,7 @@ public class CurrencyNames_zh_Hant extends OpenListResourceBundle {
             { "brb", "\u5df4\u897f\u514b\u9b6f\u85a9\u591a\u8fb2\u74e6 (1967\u20131986)" },
             { "brc", "\u5df4\u897f\u514b\u9b6f\u8cfd\u7f85 (1986\u20131989)" },
             { "bre", "\u5df4\u897f\u514b\u9b6f\u8cfd\u7f85 (1990\u20131993)" },
-            { "brl", "\u5df4\u897f\u91cc\u62c9" },
+            { "brl", "\u5df4\u897f\u96f7\u4e9e\u723e" },
             { "brn", "\u5df4\u897f\u514b\u5982\u723e\u9054\u8fb2\u74e6" },
             { "brr", "\u5df4\u897f\u514b\u9b6f\u8cfd\u7f85 (1993\u20131994)" },
             { "brz", "\u5df4\u897f\u514b\u9b6f\u8cfd\u7f85 (1942 \u20131967)" },
