@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -70,6 +66,10 @@ import sun.util.resources.OpenListResourceBundle;
 public class LocaleNames_sr_Latn extends OpenListResourceBundle {
     @Override
     protected final Object[][] getContents() {
+        final String metaValue_ccp = "\u010dakma";
+        final String metaValue_chr = "\u010deroki";
+        final String metaValue_nqo = "nko";
+        final String metaValue_vai = "vai";
         final Object[][] data = new Object[][] {
             { "001", "svet" },
             { "002", "Afrika" },
@@ -560,13 +560,16 @@ public class LocaleNames_sr_Latn extends OpenListResourceBundle {
             { "ale", "aleutski" },
             { "alt", "ju\u017enoaltajski" },
             { "ang", "staroengleski" },
+            { "ann", "obolo" },
             { "anp", "angika" },
             { "arc", "aramejski" },
             { "arn", "mapu\u010de" },
             { "arp", "arapaho" },
+            { "ars", "najdiarapski" },
             { "arw", "arava\u010dki" },
             { "asa", "asu" },
             { "ast", "asturijski" },
+            { "atj", "atikameku" },
             { "awa", "avadi" },
             { "bal", "belu\u010dki" },
             { "ban", "balijski" },
@@ -586,8 +589,9 @@ public class LocaleNames_sr_Latn extends OpenListResourceBundle {
             { "byn", "blinski" },
             { "cad", "kado" },
             { "car", "karipski" },
+            { "cay", "kajuga" },
             { "cch", "atsam" },
-            { "ccp", "\u010dakma" },
+            { "ccp", metaValue_ccp },
             { "ceb", "sebuanski" },
             { "cgg", "\u010diga" },
             { "chb", "\u010dip\u010da" },
@@ -597,13 +601,21 @@ public class LocaleNames_sr_Latn extends OpenListResourceBundle {
             { "chn", "\u010dinu\u010dki" },
             { "cho", "\u010doktavski" },
             { "chp", "\u010dipevjanski" },
-            { "chr", "\u010deroki" },
+            { "chr", metaValue_chr },
             { "chy", "\u010dejenski" },
             { "ckb", "centralni kurdski" },
+            { "clc", "\u010dilkotin" },
             { "cop", "koptski" },
+            { "crg", "mi\u010dif" },
             { "crh", "krimskotatarski" },
+            { "crj", "jugoisto\u010dni kri" },
+            { "crk", "plainskri" },
+            { "crl", "severoisto\u010dni kri" },
+            { "crm", "muzkri" },
+            { "crr", "karolin\u0161ki algonkvijan" },
             { "crs", "sej\u0161elski kreolski francuski" },
             { "csb", "ka\u0161upski" },
+            { "csw", "mo\u010dvarni kri" },
             { "dak", "dakota" },
             { "dar", "darginski" },
             { "dav", "taita" },
@@ -654,13 +666,16 @@ public class LocaleNames_sr_Latn extends OpenListResourceBundle {
             { "gwi", "gvi\u010dinski" },
             { "hai", "haida" },
             { "haw", "havajski" },
+            { "hax", "ju\u017eni haida" },
             { "hil", "hiligajnonski" },
             { "hit", "hetitski" },
             { "hmn", "hmon\u0161ki" },
             { "hsb", "gornjolu\u017ei\u010dkosrpski" },
             { "hup", "hupa" },
+            { "hur", "halkomelem" },
             { "iba", "ibanski" },
             { "ibb", "ibibio" },
+            { "ikt", "zapadnokanadski inuktitut" },
             { "ilo", "iloko" },
             { "inh", "ingu\u0161ki" },
             { "jbo", "lo\u017eban" },
@@ -679,6 +694,7 @@ public class LocaleNames_sr_Latn extends OpenListResourceBundle {
             { "kde", "makonde" },
             { "kea", "zelenortski" },
             { "kfo", "koro" },
+            { "kgp", "kaingang" },
             { "kha", "kasi" },
             { "kho", "kotane\u0161ki" },
             { "khq", "kojra \u010diini" },
@@ -698,16 +714,19 @@ public class LocaleNames_sr_Latn extends OpenListResourceBundle {
             { "ksh", "kelnski" },
             { "kum", "kumi\u010dki" },
             { "kut", "kutenaj" },
+            { "kwk", "kvakvala" },
             { "lad", "ladino" },
             { "lag", "langi" },
             { "lah", "landa" },
             { "lam", "lamba" },
             { "lez", "lezginski" },
+            { "lil", "lilut" },
             { "lkt", "lakota" },
             { "lol", "mongo" },
             { "lou", "luizijanski kreolski" },
             { "loz", "lozi" },
             { "lrc", "severni luri" },
+            { "lsm", "samia" },
             { "lua", "luba-lulua" },
             { "lui", "luisenjo" },
             { "lun", "lunda" },
@@ -732,6 +751,7 @@ public class LocaleNames_sr_Latn extends OpenListResourceBundle {
             { "min", "minangkabau" },
             { "mnc", "mand\u017eurski" },
             { "mni", "manipurski" },
+            { "moe", "inuajmun" },
             { "moh", "moho\u010dki" },
             { "mos", "mosi" },
             { "mua", "mundang" },
@@ -751,7 +771,7 @@ public class LocaleNames_sr_Latn extends OpenListResourceBundle {
             { "nnh", "ngiembun" },
             { "nog", "nogajski" },
             { "non", "staronordijski" },
-            { "nqo", "nko" },
+            { "nqo", metaValue_nqo },
             { "nso", "severni soto" },
             { "nus", "nuer" },
             { "nwc", "klasi\u010dni nevarski" },
@@ -759,6 +779,11 @@ public class LocaleNames_sr_Latn extends OpenListResourceBundle {
             { "nyn", "njankole" },
             { "nyo", "njoro" },
             { "nzi", "nzima" },
+            { "ojb", "severozapadni od\u017eibva" },
+            { "ojc", "centralni od\u017eibva" },
+            { "ojs", "od\u017eikri" },
+            { "ojw", "zapadni od\u017eibva" },
+            { "oka", "okangan" },
             { "osa", "osage" },
             { "ota", "osmanski turski" },
             { "pag", "pangasinanski" },
@@ -769,13 +794,16 @@ public class LocaleNames_sr_Latn extends OpenListResourceBundle {
             { "pcm", "nigerijski pid\u017ein" },
             { "peo", "staropersijski" },
             { "phn", "feni\u010danski" },
+            { "pis", "pid\u017ein" },
             { "pon", "ponpejski" },
+            { "pqm", "malisepasamakvodi" },
             { "prg", "pruski" },
             { "pro", "starooksitanski" },
             { "quc", "ki\u010de" },
             { "raj", "rad\u017eastanski" },
             { "rap", "rapanui" },
             { "rar", "rarotonganski" },
+            { "rhg", "rohingja" },
             { "rof", "rombo" },
             { "rom", "romski" },
             { "rup", "cincarski" },
@@ -798,6 +826,7 @@ public class LocaleNames_sr_Latn extends OpenListResourceBundle {
             { "shi", "ta\u0161elhit" },
             { "shn", "\u0161anski" },
             { "sid", "sidamo" },
+            { "slh", "ju\u017eni la\u0161utsid" },
             { "sma", "ju\u017eni sami" },
             { "smj", "lule sami" },
             { "smn", "inari sami" },
@@ -807,16 +836,20 @@ public class LocaleNames_sr_Latn extends OpenListResourceBundle {
             { "srn", "sranan tongo" },
             { "srr", "sererski" },
             { "ssy", "saho" },
+            { "str", "streicsali\u0161" },
             { "suk", "sukuma" },
             { "sus", "susu" },
             { "sux", "sumerski" },
             { "swb", "komorski" },
             { "syc", "sirija\u010dki" },
             { "syr", "sirijski" },
+            { "tce", "ju\u017eni ta\u010don" },
             { "tem", "timne" },
             { "teo", "teso" },
             { "ter", "tereno" },
             { "tet", "tetum" },
+            { "tgx", "tagi\u0161" },
+            { "tht", "tahltan" },
             { "tig", "tigre" },
             { "tiv", "tiv" },
             { "tkl", "tokelau" },
@@ -824,9 +857,11 @@ public class LocaleNames_sr_Latn extends OpenListResourceBundle {
             { "tli", "tlingit" },
             { "tmh", "tama\u0161ek" },
             { "tog", "njasa tonga" },
+            { "tok", "tokipona" },
             { "tpi", "tok pisin" },
             { "trv", "taroko" },
             { "tsi", "cim\u0161ian" },
+            { "ttm", "severni tu\u010don" },
             { "tum", "tumbuka" },
             { "tvl", "tuvalu" },
             { "twq", "tasavak" },
@@ -836,7 +871,7 @@ public class LocaleNames_sr_Latn extends OpenListResourceBundle {
             { "uga", "ugaritski" },
             { "umb", "umbundu" },
             { "und", "nepoznat jezik" },
-            { "vai", "vai" },
+            { "vai", metaValue_vai },
             { "vot", "vodski" },
             { "vun", "vund\u017eo" },
             { "wae", "valserski" },
@@ -844,12 +879,14 @@ public class LocaleNames_sr_Latn extends OpenListResourceBundle {
             { "war", "varajski" },
             { "was", "va\u0161o" },
             { "wbp", "varlpiri" },
+            { "wuu", "vu kineski" },
             { "xal", "kalmi\u010dki" },
             { "xog", "soga" },
             { "yao", "jao" },
             { "yap", "japski" },
             { "yav", "jangben" },
             { "ybb", "jemba" },
+            { "yrl", "ningatu" },
             { "yue", "kantonski" },
             { "zap", "zapote\u010dki" },
             { "zbl", "blisimboli" },
@@ -858,7 +895,9 @@ public class LocaleNames_sr_Latn extends OpenListResourceBundle {
             { "zun", "zuni" },
             { "zxx", "bez lingvisti\u010dkog sadr\u017eaja" },
             { "zza", "zaza" },
+            { "Adlm", "adlam" },
             { "Arab", "arapsko pismo" },
+            { "Aran", "nastalik" },
             { "Armi", "imperijsko aramejsko pismo" },
             { "Armn", "jermensko pismo" },
             { "Avst", "avestansko pismo" },
@@ -871,11 +910,11 @@ public class LocaleNames_sr_Latn extends OpenListResourceBundle {
             { "Brai", "brajevo pismo" },
             { "Bugi", "buginsko pismo" },
             { "Buhd", "buhidsko pismo" },
-            { "Cakm", "\u010dakmansko pismo" },
+            { "Cakm", metaValue_ccp },
             { "Cans", "ujedinjeni kanadski aborid\u017einski silabici" },
             { "Cari", "karijsko pismo" },
             { "Cham", "\u010damsko pismo" },
-            { "Cher", "\u010ceroki" },
+            { "Cher", metaValue_chr },
             { "Cirt", "cirt pismo" },
             { "Copt", "kopti\u010dko pismo" },
             { "Cprt", "kiparsko pismo" },
@@ -935,11 +974,11 @@ public class LocaleNames_sr_Latn extends OpenListResourceBundle {
             { "Mlym", "malajalamsko pismo" },
             { "Mong", "mongolsko pismo" },
             { "Moon", "mese\u010devo pismo" },
-            { "Mtei", "meitei majek pismo" },
+            { "Mtei", "meitei majek" },
             { "Mymr", "mijanmarsko pismo" },
-            { "Nkoo", "n\u2019ko pismo" },
+            { "Nkoo", metaValue_nqo },
             { "Ogam", "ogamsko pismo" },
-            { "Olck", "ol \u010diki pismo" },
+            { "Olck", "ol \u010diki" },
             { "Orkh", "orkonsko pismo" },
             { "Orya", "orijansko pismo" },
             { "Osma", "osmanjansko pismo" },
@@ -952,6 +991,7 @@ public class LocaleNames_sr_Latn extends OpenListResourceBundle {
             { "Plrd", "porald fonetsko pismo" },
             { "Prti", "pisani partian" },
             { "Rjng", "rejang pismo" },
+            { "Rohg", "hanifi" },
             { "Roro", "rongorongo pismo" },
             { "Runr", "runsko pismo" },
             { "Samr", "samaritansko pismo" },
@@ -973,17 +1013,17 @@ public class LocaleNames_sr_Latn extends OpenListResourceBundle {
             { "Tavt", "tai viet pismo" },
             { "Telu", "telugu pismo" },
             { "Teng", "tengvar pismo" },
-            { "Tfng", "tifinag pismo" },
+            { "Tfng", "tifinag" },
             { "Tglg", "Tagalog" },
             { "Thaa", "tana pismo" },
             { "Thai", "tajlandsko pismo" },
             { "Tibt", "tibetansko pismo" },
             { "Ugar", "ugaritsko pismo" },
-            { "Vaii", "vai pismo" },
+            { "Vaii", metaValue_vai },
             { "Visp", "vidljivi govor" },
             { "Xpeo", "staropersijsko pismo" },
             { "Xsux", "sumersko-akadsko kuneiform pismo" },
-            { "Yiii", "ji pismo" },
+            { "Yiii", "ji" },
             { "Zinh", "nasledno pismo" },
             { "Zmth", "matemati\u010dka notacija" },
             { "Zsye", "emod\u017ei" },
@@ -991,7 +1031,7 @@ public class LocaleNames_sr_Latn extends OpenListResourceBundle {
             { "Zxxx", "nepisani jezik" },
             { "Zyyy", "zajedni\u010dko pismo" },
             { "Zzzz", "nepoznato pismo" },
-            { "root", "rut" },
+            { "de_AT", "austrijski nema\u010dki" },
             { "de_CH", "\u0161vajcarski visoki nema\u010dki" },
             { "en_GB", "engleski (Velika Britanija)" },
             { "en_US", "engleski (Sjedinjene Ameri\u010dke Dr\u017eave)" },
@@ -1052,6 +1092,7 @@ public class LocaleNames_sr_Latn extends OpenListResourceBundle {
             { "type.nu.arab", "arapsko-indijske cifre" },
             { "type.nu.armn", "jermenski brojevi" },
             { "type.nu.beng", "bengalske cifre" },
+            { "type.nu.cakm", "\u010dakma cifre" },
             { "type.nu.deva", "devangari cifre" },
             { "type.nu.ethi", "etiopski brojevi" },
             { "type.nu.geor", "gruzijski brojevi" },
@@ -1061,6 +1102,7 @@ public class LocaleNames_sr_Latn extends OpenListResourceBundle {
             { "type.nu.hans", "pojednostavljeni kineski brojevi" },
             { "type.nu.hant", "tradicionalni kineski brojevi" },
             { "type.nu.hebr", "hebrejski brojevi" },
+            { "type.nu.java", "javanske cifre" },
             { "type.nu.jpan", "japanski brojevi" },
             { "type.nu.khmr", "kmerske cifre" },
             { "type.nu.knda", "kanada cifre" },
@@ -1068,13 +1110,15 @@ public class LocaleNames_sr_Latn extends OpenListResourceBundle {
             { "type.nu.latn", "zapadne cifre" },
             { "type.nu.mlym", "malajalam cifre" },
             { "type.nu.mong", "mongolske cifre" },
+            { "type.nu.mtei", "mitei majek cifre" },
             { "type.nu.mymr", "mijanmarske cifre" },
+            { "type.nu.olck", "ol \u010diki cifre" },
             { "type.nu.orya", "orija cifre" },
             { "type.nu.taml", "tamilski brojevi" },
             { "type.nu.telu", "telugu cifre" },
             { "type.nu.thai", "tajske cifre" },
             { "type.nu.tibt", "tibetanske cifre" },
-            { "type.nu.vaii", "Vai cifre" },
+            { "type.nu.vaii", "vai cifre" },
             { "type.ca.dangi", "dangi kalendar" },
             { "type.co.ducet", "podrazumevani Unicode redosled sortiranja" },
             { "type.lb.loose", "razmaknuti stil preloma reda" },
@@ -1083,23 +1127,24 @@ public class LocaleNames_sr_Latn extends OpenListResourceBundle {
             { "type.ca.hebrew", "hebrejski kalendar" },
             { "type.ca.indian", "Indijski nacionalni kalendar" },
             { "type.co.compat", "prethodni redosled sortiranja, zbog kompatibilnosti" },
-            { "type.co.pinyin", "Pinjin sortiranje" },
+            { "type.co.pinyin", "pinjin sortiranje" },
             { "type.co.search", "pretraga op\u0161te namene" },
-            { "type.co.stroke", "Sortiranje po broju crta" },
-            { "type.co.unihan", "Redosled sortiranja radikalnim crticama" },
+            { "type.co.stroke", "sortiranje po broju poteza" },
+            { "type.co.unihan", "redosled sortiranja radikalnih poteza" },
+            { "type.co.zhuyin", "\u017eujin" },
             { "type.d0.fwidth", "puna \u0161irina" },
             { "type.d0.hwidth", "pola \u0161irine" },
             { "type.lb.normal", "normalni stil preloma reda" },
             { "type.lb.strict", "strogi stil preloma reda" },
             { "type.m0.ungegn", "UNGEGN (BGN)" },
             { "type.ms.metric", "metri\u010dki" },
-            { "type.nu.native", "Lokalne cifre" },
+            { "type.nu.native", "lokalne cifre" },
             { "type.ca.chinese", "kineski kalendar" },
             { "type.ca.islamic", "islamski kalendar" },
             { "type.ca.iso8601", "ISO-8601 kalendar" },
             { "type.ca.persian", "persijski kalendar" },
             { "type.cf.account", "ra\u010dunovodstveni format valute" },
-            { "type.co.big5han", "Tradicionalno kinesko sortiranje" },
+            { "type.co.big5han", "tradicionalno kinesko sortiranje" },
             { "type.d0.npinyin", "Numeri\u010dka" },
             { "type.nu.arabext", "produ\u017eene arapsko-indijske cifre" },
             { "type.nu.armnlow", "mali jermenski brojevi" },
@@ -1114,8 +1159,8 @@ public class LocaleNames_sr_Latn extends OpenListResourceBundle {
             { "type.ca.ethiopic", "etiopski kalendar" },
             { "type.ca.japanese", "japanski kalendar" },
             { "type.cf.standard", "standardni format valute" },
-            { "type.co.phonetic", "Fonetski redosled sortiranja" },
-            { "type.co.reformed", "Reformisani redosled sortiranja" },
+            { "type.co.phonetic", "fonetski redosled sortiranja" },
+            { "type.co.reformed", "reformisani redosled sortiranja" },
             { "type.co.searchjl", "Pretraga prema hangul po\u010detnom suglasniku" },
             { "type.co.standard", "standardni redosled sortiranja" },
             { "type.ms.uksystem", "imperijalni" },
@@ -1123,12 +1168,13 @@ public class LocaleNames_sr_Latn extends OpenListResourceBundle {
             { "type.nu.fullwide", "cifre pune \u0161irine" },
             { "type.nu.romanlow", "mali rimski brojevi" },
             { "type.ca.gregorian", "gregorijanski kalendar" },
-            { "type.co.gb2312han", "Pojednostavljeno kinesko sortiranje" },
-            { "type.co.phonebook", "Sortiranje kao telefonski imenik" },
-            { "type.co.dictionary", "Redosled sortiranja u re\u010dniku" },
-            { "type.co.traditional", "Tradicionalno sortiranje" },
+            { "type.co.gb2312han", "pojednostavljeno kinesko sortiranje" },
+            { "type.co.phonebook", "sortiranje kao telefonski imenik" },
+            { "type.co.dictionary", "redosled sortiranja u re\u010dniku" },
+            { "type.co.traditional", "tradicionalno sortiranje" },
             { "type.nu.traditional", "Tradicionalni brojevi" },
-            { "type.ca.islamic-civil", "Islamski civilni kalendar" },
+            { "type.ca.islamic-tbla", "islamski astronomski kalendar" },
+            { "type.ca.islamic-civil", "islamski civilni kalendar" },
             { "type.ca.islamic-umalqura", "islamski kalendar (Umm al-Qura)" },
             { "type.ca.ethiopic-amete-alem", "etiopski amet alem kalendar" },
         };
