@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -110,7 +106,9 @@ public class LocaleNames_tg extends OpenListResourceBundle {
             { "BZ", "\u0411\u0435\u043b\u0438\u0437" },
             { "CA", "\u041a\u0430\u043d\u0430\u0434\u0430" },
             { "CC", "\u04b6\u0430\u0437\u0438\u0440\u0430\u04b3\u043e\u0438 \u041a\u043e\u043a\u043e\u0441 (\u041a\u0438\u043b\u0438\u043d\u0433)" },
+            { "CD", "\u041a\u043e\u043d\u0433\u043e (\u04b6\u0414\u041a)" },
             { "CF", "\u04b6\u0443\u043c\u04b3\u0443\u0440\u0438\u0438 \u0410\u0444\u0440\u0438\u049b\u043e\u0438 \u041c\u0430\u0440\u043a\u0430\u0437\u04e3" },
+            { "CG", "\u041a\u043e\u043d\u0433\u043e" },
             { "CH", "\u0428\u0432\u0435\u0439\u0442\u0441\u0430\u0440\u0438\u044f" },
             { "CI", "\u041a\u043e\u0442-\u0434\u2019\u0418\u0432\u0443\u0430\u0440" },
             { "CK", "\u04b6\u0430\u0437\u0438\u0440\u0430\u04b3\u043e\u0438 \u041a\u0443\u043a" },
@@ -339,7 +337,7 @@ public class LocaleNames_tg extends OpenListResourceBundle {
             { "dv", "\u0434\u0438\u0432\u0435\u04b3\u04e3" },
             { "dz", "\u0434\u0437\u043e\u043d\u0433\u0445\u0430" },
             { "el", "\u044e\u043d\u043e\u043d\u04e3" },
-            { "en", "\u0430\u043d\u0433\u043b\u0438\u0441\u04e3" },
+            { "en", "\u0410\u043d\u0433\u043b\u0438\u0441\u04e3" },
             { "eo", "\u044d\u0441\u043f\u0435\u0440\u0430\u043d\u0442\u043e" },
             { "es", "\u0438\u0441\u043f\u0430\u043d\u04e3" },
             { "et", "\u044d\u0441\u0442\u043e\u043d\u04e3" },
@@ -464,7 +462,7 @@ public class LocaleNames_tg extends OpenListResourceBundle {
             { "smn", "\u0438\u043d\u0430\u0440\u0438 \u0441\u0430\u043c\u04e3" },
             { "sms", "\u0441\u043a\u043e\u043b\u0442\u0438 \u0441\u0430\u043c\u04e3" },
             { "syr", "\u0441\u0443\u0440\u0438\u0451\u043d\u04e3" },
-            { "tzm", "\u0442\u0430\u043c\u0430\u0437\u0430\u0439\u0442\u0438 \u0430\u0442\u043b\u0430\u0441\u0438 \u043c\u0430\u0440\u043a\u0430\u0437\u04e3" },
+            { "tzm", "\u0442\u0430\u043c\u0430\u0437\u0430\u0439\u0442\u0438 \u0410\u0442\u043b\u0430\u0441\u0438 \u041c\u0430\u0440\u043a\u0430\u0437\u04e3" },
             { "und", "\u0437\u0430\u0431\u043e\u043d\u0438 \u043d\u043e\u043c\u0430\u044a\u043b\u0443\u043c" },
             { "Arab", "\u0410\u0440\u0430\u0431\u04e3" },
             { "Cyrl", "\u041a\u0438\u0440\u0438\u043b\u043b\u04e3" },
