@@ -26,7 +26,7 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
  * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
@@ -100,11 +100,11 @@ public class TimeZoneNames_id extends TimeZoneNamesBundle {
             };
         final String[] Cuba = new String[] {
                "Waktu Standar Kuba",
-               "",
+               "CST (Kuba)",
                "Waktu Musim Panas Kuba",
-               "",
+               "CDT (Kuba)",
                "Waktu Kuba",
-               "",
+               "CT (Kuba)",
             };
         final String[] Fiji = new String[] {
                "Waktu Standar Fiji",
@@ -290,13 +290,21 @@ public class TimeZoneNames_id extends TimeZoneNamesBundle {
                "Waktu Tonga",
                "",
             };
+        final String[] Yukon = new String[] {
+               "Waktu Yukon",
+               "",
+               "",
+               "",
+               "",
+               "",
+            };
         final String[] Alaska = new String[] {
                "Waktu Standar Alaska",
-               "",
+               "AKST",
                "Waktu Musim Panas Alaska",
-               "",
+               "AKDT",
                "Waktu Alaska",
-               "",
+               "AKT",
             };
         final String[] Amazon = new String[] {
                "Waktu Standar Amazon",
@@ -604,11 +612,11 @@ public class TimeZoneNames_id extends TimeZoneNamesBundle {
             };
         final String[] Atlantic = new String[] {
                "Waktu Standar Atlantik",
-               "",
+               "AST",
                "Waktu Musim Panas Atlantik",
-               "",
+               "ADT",
                "Waktu Atlantik",
-               "",
+               "AT",
             };
         final String[] Brasilia = new String[] {
                "Waktu Standar Brasil",
@@ -932,11 +940,11 @@ public class TimeZoneNames_id extends TimeZoneNamesBundle {
             };
         final String[] Newfoundland = new String[] {
                "Waktu Standar Newfoundland",
-               "",
+               "NST",
                "Waktu Musim Panas Newfoundland",
-               "",
+               "NDT",
                "Waktu Newfoundland",
-               "",
+               "NT",
             };
         final String[] Turkmenistan = new String[] {
                "Waktu Standar Turkmenistan",
@@ -1052,27 +1060,27 @@ public class TimeZoneNames_id extends TimeZoneNamesBundle {
             };
         final String[] America_Central = new String[] {
                "Waktu Standar Tengah",
-               "",
+               "CST",
                "Waktu Musim Panas Tengah",
-               "",
+               "CDT",
                "Waktu Tengah",
-               "",
+               "CT",
             };
         final String[] America_Eastern = new String[] {
                "Waktu Standar Timur",
-               "",
+               "EST",
                "Waktu Musim Panas Timur",
-               "",
+               "EDT",
                "Waktu Timur",
-               "",
+               "ET",
             };
         final String[] America_Pacific = new String[] {
                "Waktu Standar Pasifik",
-               "",
+               "PST",
                "Waktu Musim Panas Pasifik",
-               "",
+               "PDT",
                "Waktu Pasifik",
-               "",
+               "PT",
             };
         final String[] French_Southern = new String[] {
                "Waktu Wilayah Selatan dan Antarktika Prancis",
@@ -1092,11 +1100,11 @@ public class TimeZoneNames_id extends TimeZoneNamesBundle {
             };
         final String[] Hawaii_Aleutian = new String[] {
                "Waktu Standar Hawaii-Aleutian",
-               "",
+               "HAST",
                "Waktu Musim Panas Hawaii-Aleutian",
-               "",
+               "HADT",
                "Waktu Hawaii-Aleutian",
-               "",
+               "HAT",
             };
         final String[] Phoenix_Islands = new String[] {
                "Waktu Kepulauan Phoenix",
@@ -1108,19 +1116,19 @@ public class TimeZoneNames_id extends TimeZoneNamesBundle {
             };
         final String[] Pierre_Miquelon = new String[] {
                "Waktu Standar Saint Pierre dan Miquelon",
-               "",
+               "PMST",
                "Waktu Musim Panas Saint Pierre dan Miquelon",
-               "",
+               "PMDT",
                "Waktu Saint Pierre dan Miquelon",
-               "",
+               "PMT",
             };
         final String[] America_Mountain = new String[] {
                "Waktu Standar Pegunungan",
-               "",
+               "MST",
                "Waktu Musim Panas Pegunungan",
-               "",
+               "MDT",
                "Waktu Pegunungan",
-               "",
+               "MT",
             };
         final String[] Marshall_Islands = new String[] {
                "Waktu Kep. Marshall",
@@ -1172,11 +1180,11 @@ public class TimeZoneNames_id extends TimeZoneNamesBundle {
             };
         final String[] Greenland_Eastern = new String[] {
                "Waktu Standar Greenland Timur",
-               "",
+               "EGST",
                "Waktu Musim Panas Greenland Timur",
-               "",
+               "EGDT",
                "Waktu Greenland Timur",
-               "",
+               "EGT",
             };
         final String[] Greenland_Western = new String[] {
                "Waktu Standar Greenland Barat",
@@ -1287,7 +1295,6 @@ public class TimeZoneNames_id extends TimeZoneNamesBundle {
             { "Asia/Hovd", Hovd },
             { "Asia/Omsk", Omsk },
             { "Asia/Oral", Kazakhstan_Western },
-            { "Asia/Amman", Europe_Eastern },
             { "Asia/Aqtau", Kazakhstan_Western },
             { "Asia/Chita", Yakutsk },
             { "Asia/Dhaka", Bangladesh },
@@ -1383,7 +1390,6 @@ public class TimeZoneNames_id extends TimeZoneNamesBundle {
             { "America/Thule", Atlantic },
             { "Asia/Ashgabat", Turkmenistan },
             { "Asia/Calcutta", India },
-            { "Asia/Damascus", Europe_Eastern },
             { "Asia/Dushanbe", Tajikistan },
             { "Asia/Jayapura", Indonesia_Eastern },
             { "Asia/Katmandu", Nepal },
@@ -1446,7 +1452,7 @@ public class TimeZoneNames_id extends TimeZoneNamesBundle {
             { "America/Cancun", America_Eastern },
             { "America/Cayman", America_Eastern },
             { "America/Cuiaba", Amazon },
-            { "America/Dawson", America_Mountain },
+            { "America/Dawson", Yukon },
             { "America/Guyana", Guyana },
             { "America/Havana", Cuba },
             { "America/Inuvik", America_Mountain },
@@ -1522,7 +1528,7 @@ public class TimeZoneNames_id extends TimeZoneNamesBundle {
             { "America/Moncton", Atlantic },
             { "America/Nipigon", America_Eastern },
             { "America/Noronha", Noronha },
-            { "America/Ojinaga", America_Mountain },
+            { "America/Ojinaga", America_Central },
             { "America/Tijuana", America_Pacific },
             { "America/Toronto", America_Eastern },
             { "America/Tortola", Atlantic },
@@ -1608,7 +1614,7 @@ public class TimeZoneNames_id extends TimeZoneNamesBundle {
             { "America/Araguaina", Brasilia },
             { "America/Boa_Vista", Amazon },
             { "America/Catamarca", Argentina },
-            { "America/Chihuahua", Mexico_Pacific },
+            { "America/Chihuahua", America_Central },
             { "America/Fortaleza", Brasilia },
             { "America/Glace_Bay", Atlantic },
             { "America/Goose_Bay", Atlantic },
@@ -1653,7 +1659,7 @@ public class TimeZoneNames_id extends TimeZoneNamesBundle {
             { "America/Paramaribo", Suriname },
             { "America/Rio_Branco", Acre },
             { "America/St_Vincent", Atlantic },
-            { "America/Whitehorse", America_Mountain },
+            { "America/Whitehorse", Yukon },
             { "Antarctica/McMurdo", New_Zealand },
             { "Antarctica/Rothera", Rothera },
             { "Asia/Yekaterinburg", Yekaterinburg },
@@ -1696,6 +1702,7 @@ public class TimeZoneNames_id extends TimeZoneNamesBundle {
             { "Antarctica/Macquarie", Australia_Eastern },
             { "Pacific/Port_Moresby", Papua_New_Guinea },
             { "America/Cambridge_Bay", America_Mountain },
+            { "America/Ciudad_Juarez", America_Mountain },
             { "America/Coral_Harbour", America_Eastern },
             { "America/Indiana/Vevay", America_Eastern },
             { "America/Lower_Princes", Atlantic },
