@@ -26,7 +26,7 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
  * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
@@ -290,6 +290,14 @@ public class TimeZoneNames_zh extends TimeZoneNamesBundle {
                "\u6c64\u52a0\u65f6\u95f4",
                "",
             };
+        final String[] Yukon = new String[] {
+               "\u80b2\u7a7a\u65f6\u95f4",
+               "",
+               "",
+               "",
+               "",
+               "",
+            };
         final String[] Alaska = new String[] {
                "\u963f\u62c9\u65af\u52a0\u6807\u51c6\u65f6\u95f4",
                "",
@@ -1003,7 +1011,7 @@ public class TimeZoneNames_zh extends TimeZoneNamesBundle {
                "",
             };
         final String[] DumontDUrville = new String[] {
-               "\u8fea\u8499\u8fea\u5c14\u7ef4\u5c14\u65f6\u95f4",
+               "\u8fea\u8499\u00b7\u8fea\u7ef4\u5c14\u65f6\u95f4",
                "",
                "",
                "",
@@ -1287,7 +1295,6 @@ public class TimeZoneNames_zh extends TimeZoneNamesBundle {
             { "Asia/Hovd", Hovd },
             { "Asia/Omsk", Omsk },
             { "Asia/Oral", Kazakhstan_Western },
-            { "Asia/Amman", Europe_Eastern },
             { "Asia/Aqtau", Kazakhstan_Western },
             { "Asia/Chita", Yakutsk },
             { "Asia/Dhaka", Bangladesh },
@@ -1383,7 +1390,6 @@ public class TimeZoneNames_zh extends TimeZoneNamesBundle {
             { "America/Thule", Atlantic },
             { "Asia/Ashgabat", Turkmenistan },
             { "Asia/Calcutta", India },
-            { "Asia/Damascus", Europe_Eastern },
             { "Asia/Dushanbe", Tajikistan },
             { "Asia/Jayapura", Indonesia_Eastern },
             { "Asia/Katmandu", Nepal },
@@ -1446,7 +1452,7 @@ public class TimeZoneNames_zh extends TimeZoneNamesBundle {
             { "America/Cancun", America_Eastern },
             { "America/Cayman", America_Eastern },
             { "America/Cuiaba", Amazon },
-            { "America/Dawson", America_Mountain },
+            { "America/Dawson", Yukon },
             { "America/Guyana", Guyana },
             { "America/Havana", Cuba },
             { "America/Inuvik", America_Mountain },
@@ -1522,7 +1528,7 @@ public class TimeZoneNames_zh extends TimeZoneNamesBundle {
             { "America/Moncton", Atlantic },
             { "America/Nipigon", America_Eastern },
             { "America/Noronha", Noronha },
-            { "America/Ojinaga", America_Mountain },
+            { "America/Ojinaga", America_Central },
             { "America/Tijuana", America_Pacific },
             { "America/Toronto", America_Eastern },
             { "America/Tortola", Atlantic },
@@ -1608,7 +1614,7 @@ public class TimeZoneNames_zh extends TimeZoneNamesBundle {
             { "America/Araguaina", Brasilia },
             { "America/Boa_Vista", Amazon },
             { "America/Catamarca", Argentina },
-            { "America/Chihuahua", Mexico_Pacific },
+            { "America/Chihuahua", America_Central },
             { "America/Fortaleza", Brasilia },
             { "America/Glace_Bay", Atlantic },
             { "America/Goose_Bay", Atlantic },
@@ -1653,7 +1659,7 @@ public class TimeZoneNames_zh extends TimeZoneNamesBundle {
             { "America/Paramaribo", Suriname },
             { "America/Rio_Branco", Acre },
             { "America/St_Vincent", Atlantic },
-            { "America/Whitehorse", America_Mountain },
+            { "America/Whitehorse", Yukon },
             { "Antarctica/McMurdo", New_Zealand },
             { "Antarctica/Rothera", Rothera },
             { "Asia/Yekaterinburg", Yekaterinburg },
@@ -1696,6 +1702,7 @@ public class TimeZoneNames_zh extends TimeZoneNamesBundle {
             { "Antarctica/Macquarie", Australia_Eastern },
             { "Pacific/Port_Moresby", Papua_New_Guinea },
             { "America/Cambridge_Bay", America_Mountain },
+            { "America/Ciudad_Juarez", America_Mountain },
             { "America/Coral_Harbour", America_Eastern },
             { "America/Indiana/Vevay", America_Eastern },
             { "America/Lower_Princes", Atlantic },
@@ -1905,6 +1912,7 @@ public class TimeZoneNames_zh extends TimeZoneNamesBundle {
             { "timezone.excity.Indian/Mayotte", "\u9a6c\u7ea6\u7279" },
             { "timezone.excity.Indian/Reunion", "\u7559\u5c3c\u6c6a" },
             { "timezone.excity.Pacific/Easter", "\u590d\u6d3b\u8282\u5c9b" },
+            { "timezone.excity.Pacific/Kanton", "\u574e\u987f\u5c9b" },
             { "timezone.excity.Pacific/Kosrae", "\u5e93\u8d5b\u57c3" },
             { "timezone.excity.Pacific/Majuro", "\u9a6c\u6731\u7f57" },
             { "timezone.excity.Pacific/Midway", "\u4e2d\u9014\u5c9b" },
@@ -2045,7 +2053,7 @@ public class TimeZoneNames_zh extends TimeZoneNamesBundle {
             { "timezone.excity.America/St_Thomas", "\u5723\u6258\u9a6c\u65af" },
             { "timezone.excity.America/Vancouver", "\u6e29\u54e5\u534e" },
             { "timezone.excity.Antarctica/Mawson", "\u83ab\u68ee" },
-            { "timezone.excity.Antarctica/Palmer", "\u5e15\u9ed8\u5c14" },
+            { "timezone.excity.Antarctica/Palmer", "\u5e15\u5c14\u9ed8" },
             { "timezone.excity.Antarctica/Vostok", "\u6c83\u65af\u6258\u514b" },
             { "timezone.excity.Asia/Kuala_Lumpur", "\u5409\u9686\u5761" },
             { "timezone.excity.Asia/Novokuznetsk", "\u65b0\u5e93\u5179\u6d85\u8328\u514b" },
@@ -2143,7 +2151,7 @@ public class TimeZoneNames_zh extends TimeZoneNamesBundle {
             { "timezone.excity.America/Argentina/Ushuaia", "\u4e4c\u65af\u6000\u4e9a" },
             { "timezone.excity.America/Indiana/Tell_City", "\u5370\u7b2c\u5b89\u7eb3\u5dde\u7279\u5c14\u57ce" },
             { "timezone.excity.America/Indiana/Vincennes", "\u5370\u7b2c\u5b89\u7eb3\u5dde\u6e29\u68ee\u65af" },
-            { "timezone.excity.Antarctica/DumontDUrville", "\u8fea\u8499\u8fea\u5c14\u7ef4\u5c14" },
+            { "timezone.excity.Antarctica/DumontDUrville", "\u8fea\u8499\u00b7\u8fea\u7ef4\u5c14" },
             { "timezone.excity.America/Argentina/La_Rioja", "\u62c9\u91cc\u5965\u54c8" },
             { "timezone.excity.America/Argentina/San_Juan", "\u5723\u80e1\u5b89" },
             { "timezone.excity.America/Argentina/San_Luis", "\u5723\u8def\u6613\u65af" },
