@@ -26,7 +26,7 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
  * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
@@ -290,6 +290,14 @@ public class TimeZoneNames_zh_Hant extends TimeZoneNamesBundle {
                "\u6771\u52a0\u6642\u9593",
                "",
             };
+        final String[] Yukon = new String[] {
+               "\u80b2\u7a7a\u5730\u5340\u6642\u9593",
+               "",
+               "",
+               "",
+               "",
+               "",
+            };
         final String[] Alaska = new String[] {
                "\u963f\u62c9\u65af\u52a0\u6a19\u6e96\u6642\u9593",
                "AKST",
@@ -1287,7 +1295,6 @@ public class TimeZoneNames_zh_Hant extends TimeZoneNamesBundle {
             { "Asia/Hovd", Hovd },
             { "Asia/Omsk", Omsk },
             { "Asia/Oral", Kazakhstan_Western },
-            { "Asia/Amman", Europe_Eastern },
             { "Asia/Aqtau", Kazakhstan_Western },
             { "Asia/Chita", Yakutsk },
             { "Asia/Dhaka", Bangladesh },
@@ -1383,7 +1390,6 @@ public class TimeZoneNames_zh_Hant extends TimeZoneNamesBundle {
             { "America/Thule", Atlantic },
             { "Asia/Ashgabat", Turkmenistan },
             { "Asia/Calcutta", India },
-            { "Asia/Damascus", Europe_Eastern },
             { "Asia/Dushanbe", Tajikistan },
             { "Asia/Jayapura", Indonesia_Eastern },
             { "Asia/Katmandu", Nepal },
@@ -1446,7 +1452,7 @@ public class TimeZoneNames_zh_Hant extends TimeZoneNamesBundle {
             { "America/Cancun", America_Eastern },
             { "America/Cayman", America_Eastern },
             { "America/Cuiaba", Amazon },
-            { "America/Dawson", America_Mountain },
+            { "America/Dawson", Yukon },
             { "America/Guyana", Guyana },
             { "America/Havana", Cuba },
             { "America/Inuvik", America_Mountain },
@@ -1522,7 +1528,7 @@ public class TimeZoneNames_zh_Hant extends TimeZoneNamesBundle {
             { "America/Moncton", Atlantic },
             { "America/Nipigon", America_Eastern },
             { "America/Noronha", Noronha },
-            { "America/Ojinaga", America_Mountain },
+            { "America/Ojinaga", America_Central },
             { "America/Tijuana", America_Pacific },
             { "America/Toronto", America_Eastern },
             { "America/Tortola", Atlantic },
@@ -1608,7 +1614,7 @@ public class TimeZoneNames_zh_Hant extends TimeZoneNamesBundle {
             { "America/Araguaina", Brasilia },
             { "America/Boa_Vista", Amazon },
             { "America/Catamarca", Argentina },
-            { "America/Chihuahua", Mexico_Pacific },
+            { "America/Chihuahua", America_Central },
             { "America/Fortaleza", Brasilia },
             { "America/Glace_Bay", Atlantic },
             { "America/Goose_Bay", Atlantic },
@@ -1653,7 +1659,7 @@ public class TimeZoneNames_zh_Hant extends TimeZoneNamesBundle {
             { "America/Paramaribo", Suriname },
             { "America/Rio_Branco", Acre },
             { "America/St_Vincent", Atlantic },
-            { "America/Whitehorse", America_Mountain },
+            { "America/Whitehorse", Yukon },
             { "Antarctica/McMurdo", New_Zealand },
             { "Antarctica/Rothera", Rothera },
             { "Asia/Yekaterinburg", Yekaterinburg },
@@ -1696,6 +1702,7 @@ public class TimeZoneNames_zh_Hant extends TimeZoneNamesBundle {
             { "Antarctica/Macquarie", Australia_Eastern },
             { "Pacific/Port_Moresby", Papua_New_Guinea },
             { "America/Cambridge_Bay", America_Mountain },
+            { "America/Ciudad_Juarez", America_Mountain },
             { "America/Coral_Harbour", America_Eastern },
             { "America/Indiana/Vevay", America_Eastern },
             { "America/Lower_Princes", Atlantic },
@@ -1905,6 +1912,7 @@ public class TimeZoneNames_zh_Hant extends TimeZoneNamesBundle {
             { "timezone.excity.Indian/Mayotte", "\u99ac\u7d04\u7279\u5cf6" },
             { "timezone.excity.Indian/Reunion", "\u7559\u5c3c\u65fa\u5cf6" },
             { "timezone.excity.Pacific/Easter", "\u5fa9\u6d3b\u5cf6" },
+            { "timezone.excity.Pacific/Kanton", "\u574e\u9813\u5cf6" },
             { "timezone.excity.Pacific/Kosrae", "\u79d1\u65af\u745e" },
             { "timezone.excity.Pacific/Majuro", "\u99ac\u6731\u8afe" },
             { "timezone.excity.Pacific/Midway", "\u4e2d\u9014\u5cf6" },
