@@ -26,7 +26,7 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
  * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
@@ -378,7 +378,6 @@ public class TimeZoneNames_zh_Hant_HK extends TimeZoneNamesBundle {
             { "America/Belize", America_Central },
             { "America/Cancun", America_Eastern },
             { "America/Cayman", America_Eastern },
-            { "America/Dawson", America_Mountain },
             { "America/Guyana", Guyana },
             { "America/Inuvik", America_Mountain },
             { "America/Merida", America_Central },
@@ -395,7 +394,7 @@ public class TimeZoneNames_zh_Hant_HK extends TimeZoneNamesBundle {
             { "America/Managua", America_Central },
             { "America/Nipigon", America_Eastern },
             { "America/Noronha", Noronha },
-            { "America/Ojinaga", America_Mountain },
+            { "America/Ojinaga", America_Central },
             { "America/Tijuana", America_Pacific },
             { "America/Toronto", America_Eastern },
             { "Indian/Maldives", Maldives },
@@ -411,6 +410,7 @@ public class TimeZoneNames_zh_Hant_HK extends TimeZoneNamesBundle {
             { "Indian/Mauritius", Mauritius },
             { "Pacific/Funafuti", Tuvalu },
             { "Pacific/Pitcairn", Pitcairn },
+            { "America/Chihuahua", America_Central },
             { "America/Guatemala", America_Central },
             { "America/Guayaquil", Ecuador },
             { "America/Matamoros", America_Central },
@@ -424,7 +424,6 @@ public class TimeZoneNames_zh_Hant_HK extends TimeZoneNamesBundle {
             { "America/Grand_Turk", America_Eastern },
             { "America/Louisville", America_Eastern },
             { "America/Paramaribo", Suriname },
-            { "America/Whitehorse", America_Mountain },
             { "Africa/Johannesburg", Africa_Southern },
             { "America/El_Salvador", America_Central },
             { "America/Fort_Nelson", America_Mountain },
@@ -441,6 +440,7 @@ public class TimeZoneNames_zh_Hant_HK extends TimeZoneNamesBundle {
             { "America/Rankin_Inlet", America_Central },
             { "Pacific/Port_Moresby", Papua_New_Guinea },
             { "America/Cambridge_Bay", America_Mountain },
+            { "America/Ciudad_Juarez", America_Mountain },
             { "America/Coral_Harbour", America_Eastern },
             { "America/Indiana/Vevay", America_Eastern },
             { "America/Swift_Current", America_Central },
